(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     95823,       2481]*)
(*NotebookOutlinePosition[     97326,       2526]*)
(*  CellTagsIndexPosition[     97282,       2522]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    RowBox[{"\n", 
      StyleBox[" ",
        FontFamily->"Helvetica",
        FontSize->16], 
      StyleBox[\(THE\ AVF\ PROGRAMS\),
        FontFamily->"Helvetica",
        FontSize->16,
        FontVariations->{"Underline"->True}]}]], "Input"],

Cell[BoxData[
    \(\(\ \ \ \ \ \ \ \ \ \ HUGO\ WAHLQUIST\)\)], "Input"],

Cell[CellGroupData[{

Cell["I. Introduction", "Section",
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontSize->16,
  FontTracking->"Condensed"],

Cell[BoxData[
    \(\((Note : \ 
        This\ is\ a\ text\ only\ file\ which\ may\ best\ be\ printed\ out\ \
for\ reading . \n\t\ \ \ \ \ \ \ \ None\ of\ the\ sample\ \ statements\ \
herein\ \ is\ \(\(executable\)\(.\)\))\)\)], "Input",
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(This\ file\ contains\ a\ general\ description\ of\ the\ \
structure\ \ and\ capabilities\ \ of\ AVF . \n
        It\ covers\ the\ basic\ information\ and\ operations\ needed\ to\ \
understand\ the\ \ program, \n
    but\ will\ not\ serve\ as\ a\ detailed\ manual . \ 
        All\ the\ operations\ described\ here, \ and\ many\), "\n", 
    \(additional\ ones, \ are\ introduced, 
    explained, \(and\ used\ in\ the\ demonstration\ programs;\)\n
    AVF_Commands . nb, AVF_Demo . nb, \ CAV_Demo . nb, 
    etc . \n\t\t\nAfter\ reading\ this\ Introduction, \ 
    those\ programs\ can\ be\ run\ to\ see\ how\ the\ program\), "\n", 
    \(works\ in\ detail . \ 
        The\ programs\ assume\ that\ \ "\<AVFinit\>"\ \ has\ been\ executed\ \
\((if\ necessary)\), \n
    so\ the\ AVF_Files\ and\ CliffordAlgebras\ folders\ can\ be\ accessed . \ \
\t\ \ \n\nThere\ are\ also\ some\ sample\ calculations\ in\ the\ files, 
    CartanCharacters . nb\ \ \ and\ \ \), "\n", 
    \(Riemann . nb\ , \((which\ have\ their\ own\ instructions)\), \ 
    and\ can\ \ serve\ as\ patterns\ for\ \), "\n", 
    \(similar\ calculations . \ 
        They\ call\ some\ other\ utility\ programs\ to\ implement\ the\ \
specific\), "\n", 
    \(types\ of\ AVF\ calculations\ they\ perform . \n\t\t\ \n
        Section\ VII\ \ at\ the\ end\ of\ this\ document\ contains\ a\ \
summary\ of\ the\ complete\ set\ of\), "\n", 
    \(variable\ and\ function\ names\ together\ with\ a\ brief\ description\ \
for\ each\ \(\(entry\)\(.\)\)\)}], "Input",
  PageBreakBelow->Automatic,
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["II. Basic Structures", "Section",
  PageBreakAbove->True,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontSize->16,
  FontTracking->"Condensed"],

Cell[BoxData[{
    \(An\ \ algebra - valued - form \((AVF)\)\ is\ a\ multinomial, 
    each\ term\ of\ which\ is\ \ a\ product\), 
    \(of\ three\ types\ of\ factors; \n\n
    \((\ scalar\ coefficient\ )\) 
      \((\ exterior\ product\ of\ basis\ forms\ )\) 
      \((\ a\ single\ \ algebra\ element\ )\)\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  TextJustification->0,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(For\ example, \)\)], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\ \ 
    sampleterm = 
      \((2  z\^3\ Sin[x])\) 
        \((\[Theta]\_1\[Wedge]\[Theta]\_4\[Wedge]\[Theta]\_2)\) 
        \((e\_3)\)\ \ \ \ \ \ \ \ \ 
        \((parentheses\ optional)\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ [1]
          \)\)], "Input",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(Any\ of\ these\ factors\ may\ be\ omitted\ in\ any\ term\ of\ an\ AVF\ 
      \(expression.\)\)], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["IIa. Fundamental Lists", "Subsection",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontSize->12,
  FontTracking->"Condensed"],

Cell[BoxData[{
    \(The\ algebraic\ categories\ of\ the\ variables\ involved\ are\ \
established\ by\ their\ membership\ \), "\n", 
    \(\(in\ one\ of\ three\ fundamental\ lists\ of\ arbitrarily\ chosen\ \
symbols\ with\ the\ reserved\ names;\)\), "\n", 
    \("\<scalars\>", forms "\< and \>" elements \*"\"\<.\>"\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(After\ calling\ up\ the\ AVF\ program\ with\ \ << AVF.m\ \ \ and\ 
      before\ starting\ a\ calculation, 
    these\ lists\ may\ be\ defined\ 
      \((and\ can\ be\ changed\ at\ any\ later\ time)\)\ by\ the\ 
      \(commands : \)\t\)\)], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(\t\t\tmakescalars[{list\ of\ scalar\ symbols}]\n\), "\n", 
    \(\t\t\t\(makeforms[{list\ of\ 1 - 
            form\ symbols}]\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ [2]\n\), "\n", 
    \(\t\t\tmakeelements[{list\ of\ algebra - element\ symbols}]\)}], "Input",\

  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(For\ instance, 
    the\ following\ start - 
      up\ commands\ \((which\ can\ be\ executed\ in\ any\ order)\)\), 
    \(would\ establish\ the\ properties\ of\ the\ symbols\ in\ the\ 
      "\<sampleterm\>"\ used\ \(in\ [1] : \)\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    RowBox[{
      \(makeforms[{\[Theta]\_1, \[Theta]\_2, \[Theta]\_3, \[Theta]\_4}]\)}], 
    RowBox[{
      StyleBox[\({\[Theta]\_1, \[Theta]\_2, \[Theta]\_3, \[Theta]\_4}\),
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"Underline"->False,
        "Outline"->False,
        "Shadow"->False}], "\n"}], 
  \(\(makescalars[{x, y, z}]
        \)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ [3]\), 
    RowBox[{
      StyleBox[\({x, y, z}\),
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"Underline"->False,
        "Outline"->False,
        "Shadow"->False}], "\n"}], \(makeelements[{e\_0, e\_1, e\_2, e\_3}]\),
   
    RowBox[{
      StyleBox[\({e\_0, e\_1, e\_2, e\_3}\),
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"Underline"->False,
        "Outline"->False,
        "Shadow"->False}], "\t"}]}], "Input",
  CellLabel->"In[6]:=",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    RowBox[{\(Since\ their\ names\ are\ protected\), ",", " ", 
      RowBox[{
        RowBox[{"the", " ", 
          StyleBox[
            RowBox[{"lis", 
              StyleBox["ts",
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontTracking->"Plain",
                FontVariations->{"Underline"->False,
                "Outline"->False,
                "Shadow"->False}]}]], " ", 
          StyleBox["cannot",
            FontVariations->{"Underline"->True}], "  ", 
          StyleBox["be",
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["defined",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["by",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["simple",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["assignments",
            FontWeight->"Plain"]}], 
        StyleBox[";",
          FontWeight->"Plain"], "\n", \(such\ as\ for\ example\)}], ",", 
      \(scalars = {x, y, z}\), ",", 
      StyleBox[" ",
        FontWeight->"Plain"], 
      StyleBox[\(although\ their\ values\ may\ always\ be\ viewed\),
        FontWeight->"Plain"]}], 
    StyleBox[
      \(by\ typing\ their\ names.\n\t\t\nIf\ the\ "\<make\>"\ commands\ are\ 
        not\ executed, 
      the\ lists\ will\ have\ the\ default\ \(values : \nscalars\) = {}, \ 
      forms = {}, \ and\ elements = \({identity}.\)\),
      FontWeight->"Plain"]}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    StyleBox[\(The\ "\<make\>"\ commands\ are\ needed\ to\ perform\ \ several\
\ essential\ chores\ in\ addition\ to\),
      FontWeight->"Plain"], "\n", 
    RowBox[{
      RowBox[{
        RowBox[{"defining", 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["the",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["values",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["of",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["the",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["respective",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["lists",
              FontWeight->"Plain"], 
            StyleBox[".",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], "For"}], " ", "instance"}], 
        ",", \(the\ "\<make\>"\ commands\ for\)}], 
      StyleBox["  ",
        FontWeight->"Plain"]}], "\n", 
    RowBox[{
      RowBox[{
        StyleBox["\"\<scalars\>\"",
          FontWeight->"Plain"], \((0 - forms)\), " ", "and", "  ", 
        "\"\<forms\>\"", " ", \((1 - forms)\), " ", "automatically", "  ", 
        "generate", " ", "lists", "  ", "of", " ", "symbols"}], 
      " "}], "\n", \(for\ their\ exterior\ derivatives\ with\ reserved\ \
names, "\<dscalars\>"\ , \ "\<dforms\>"; \ e . g . , \)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    RowBox[{" ", "dscalars"}], "\n", 
    RowBox[{
      StyleBox[\({dx, dy, dz}\),
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"Underline"->False,
        "Outline"->False,
        "Shadow"->False}], "\n", 
      "                                                                       \
                                                                              \
                              ", "[", "4", "]"}], "\n", 
    RowBox[{" ", "dforms"}], "\n", 
    RowBox[{
      StyleBox[\({d\[Theta]\_1, d\[Theta]\_2, d\[Theta]\_3, d\[Theta]\_4}\),
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"Underline"->False,
        "Outline"->False,
        "Shadow"->False}], "\t\t\t\t\t\t\t\t     \t  \t"}]}], "Input",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(Furthermore, \ 
    the\ "\<dscalars\>"\ list\ is\ automatically\ joined\ to\ the\ 
      "\<forms\>"\ list, \)], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    RowBox[{" ", 
      \(forms\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ [5]\)}], 
    RowBox[{
      StyleBox[
        \({\[Theta]\_1, \[Theta]\_2, \[Theta]\_3, \[Theta]\_4, dx, dy, dz}\),
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"Underline"->False,
        "Outline"->False,
        "Shadow"->False}], 
      "                                                                      \
"}]}], "Input",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(and\ all\ members\ of\ "\<forms\>"\ \ are\ treated\ as\ independent\ 1
         - forms\ \ generating\ the\), 
    \(Grassmann\ \ algebra\ based\ on\ them.\n\nThe\ algebra\ "\<elements\>"\ 
      are\ assumed\ to\ be\ constant.\n\t\t\nA\ "\<make\>"\ command\ creates\ 
      a\ new\ list\ each\ time\ it\ is\ used; it\ does\ not\ extend\ the\), 
    \(existing\ list.\ So, for\ example, 
    makescalars[{}]\ \ deletes\ all\ scalars, and\), 
    \(makeforms[{}]\ \ deletes\ all\ 1 - forms, 
    except\ for\ the\ members\ of\ "\<dscalars\>"\ \((if\ any)\), \n
    which\ can\ be\ removed\ only\ by\ deleting\ the\ 
      scalars.\n\t\t\ \nExtending\ a\ list\ can\ be\ accomplished\ by; e.g., 
     : \)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\(\t\ \)\(\(makescalars[
        Join[scalars, {list\ of\ additional\ scalars}]]\)\ \ \ \ \ \ \ \ \ \ \
\ \ [6]\)\)\)], "Input",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(Many\ other\ lists\ \((described\ below)\)\ are\ also\ generated\ 
      automatically\ by\ these\ commands, \n
    or\ else\ created\ by\ their\ own\ "\<make\>"\ \(commands.\)\)], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IIb. Symbols", "Subsection",
  PageBreakAbove->True,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontFamily->"Courier",
  FontSize->12,
  FontTracking->"Condensed"],

Cell[BoxData[{
    \(There\ is\ nothing\ special\ about\ the\ particular\ symbols\ used\ for\
\ the\ members\), "\n", 
    \(of "\<scalars\>", "\<forms\>", 
    and "\<elements\>"\ \ in\ the\ examples\ displayed\ here . \ 
        The\ symbols\), "\n", 
    \(in\ these\ lists\ may\ be\ any\ variable\ names\ acceptable\ to\ \
Mathematica, and\ may\ include\), "\n", 
    \(multiple\ subscripts, overscripts, underscripts, \(\(etc\)\(.\)\), 
    but\ not\ superscripts, \n\(\(which\)\(\ \)\(are\)\(\ \)\(always\)\(\ \
\)\(interpreted\)\(\ \)\(as\)\(\ \)\(\(exponents\)\(.\)\)\(\t\)\)\)}], "Input",\

  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(These\ symbols\ are\ the\ "\<atoms\>"\ out\ of\ which\ expressions\ \
will\ be\ built . \ They\ \), "\n", 
    \(themselves\ must\ be\ elementary\ objects\  - \ simple\ names\  - \ 
      neither\ expressions\ nor\), "\n", 
    \(functions, and\ must\ never\ have\ assigned\ values . \ For\ example, 
    neither\  - x\ \ nor\ f[x]\), "\n", 
    \(is\ an\ acceptable\ candidate\ for\ membership\ in\ "\<scalars\>", 
    and\ \ \((y\ dz\  - \ z\ dy)\)\ is\ not\), "\n", 
    \(\(\(a\)\(\ \)\(valid\)\(\ \)\(member\)\(\ \)\(of\)\(\ \)\(\("\<forms\>"\
\)\(.\)\)\(\ \)\)\)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    RowBox[{\(Any\ \ relations\ between\ the\ independent\ members\ of \
"\<scalars\>"\ or\ "\<forms\>" such\ as\), ",", "\n", 
      " ", \(y \[Rule] \(y[x]\ or\ \[Theta]\_1 \[Rule] \((y\ dz\  - \ 
              z\ dy)\)\)\), ",", 
      RowBox[{"can", " ", 
        RowBox[{"(", 
          StyleBox[\(and\ must\),
            FontVariations->{"Underline"->True}], ")"}], " ", "be", " ", 
        "handled", " ", "by", " ", "using", " ", "replacement", " ", 
        "rules"}], ",", "\n", \(not\ by\ \ assignments . \ Of\ course\), 
      ",", \(nothing\ forbids\ defining\ a\ 1 - form\), 
      ",", \(\[Sigma]\_1 = y\ dz - z\ dy\), ",", "\n", \(by\ assignment; 
      it\ simply\ becomes\ an\ AVF . \ But\ \(\[Sigma]\_1\) 
        is\ not\ then\ an\ independent\ generator\), ",", 
      "\n", \(or\ "\<basis-form\>"\), 
      ",", \(and\ so\ is\ not\ eligible\ for\ membership\ in\ the "\<forms\>"\
\ \(\(list\)\(.\)\)\)}]], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(The\ "\<make\>"\ functions\ perform\ a\ screening\ test\ of\ their\ \
argument\ lists . \ The\ test\ will\ \), "\n", 
    \(cause\ an\ Interrupt\ if\ it\ finds\ a\ problem\ \ and\ indicate\ where\
\ it\ is, but\ it\ will\ not\ detect\ \), "\n", 
    \(all\ possible\ errors . \ Most\ often, \ 
    errors\ \ occur\ because\ a\ name\ has\ had\ a\ prior\ assignment . \n
        The\ Interrupt\ can\ be\ handled\ by\ selecting\ Abort\ in\ the\ \
window, modifying\ the\), "\n", 
    \(input\ argument \((e . g . , clearing\ any\ assigned\ values)\), 
    and\ re - executing\ the\ \), "\n", 
    \("\<make\>"\ command . 
          Sometimes\ the\ easiest\ fix\ may\ be\ to\ Quit\ and\ re - \
\(\(start\)\(\ \)\(the\)\(\ \)\(\(Kernel\)\(.\)\)\(\t\)\)\)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(The\ different\ lists\ must\ have\ no\ members\ in\ common\ except\ for\
\ the\ automatic\ inclusion\), "\n", 
    \(of\ "\<dscalars\>"\ in\ "\<forms\>" . \ 
        Any\ simple\ variable\ in\ \ an\ \ AVF\ expression\ which\ is\ not\), \
"\n", 
    \(a\ member\ of\ any\ of\ these\ lists\ will\ be\ treated\ as\ a\ \
constant\ scalar\ \(\(parameter\)\(.\)\)\)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IIc. Algebras", "Subsection",
  PageBreakAbove->True,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontSize->12,
  FontTracking->"Condensed"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"The", 
          StyleBox[" ",
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox["algebras",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox[" ",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox["of",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox[" ",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox["scalars",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox[" ",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox["and",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox[" ",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox["differential",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox[" ",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox["forms",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox[" ",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox["are",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox[" ",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox["fixed",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}]}], 
        StyleBox[",",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], 
        StyleBox[" ",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], 
        RowBox[{
          StyleBox["but",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox[" ",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox["the",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox[" ",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox["algebra",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox[" ",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], "of"}]}], " "}], 
  \("\<elements\>"\ \ must\ be\ specified\ in\ a\ multiplication\ table\ 
      defining\ the\ desired\ algebra.\nThis\ is\ accomplished\ by\ inputting
      \ a\ matrix\ with\ the\ appropriate\ products.\ For\ example, \n
    for\ an\ algebra\ with\ four\ generators 
      \((say, \ elements = {e\_0, e\_1, e\_2, e\_3})\), \ the\ matrix\), 
  \(\((here\ called\ producttable)\), \ 
    would\ have\ the\ following\ \(structure : \)\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\(producttable \
= {{\(e\_0\) e\_0, \(e\_0\) e\_1, \(e\_0\) e\_2, \(e\_0\) 
            e\_3}, \n\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ {\(e\_1\) e\_0, \(e\_1\) e\_1, \(e\_1\) 
            e\_2, \(e\_1\) 
            e\_3}, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \([7]\)\n\t\t\ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ {\(e\_2\
\) e\_0, \(e\_2\) e\_1, \(e\_2\) e\_2, \(e\_2\) 
              e\_3}, \n\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ {\(e\_3\) e\_0, \(e\_3\) e\_1, \(e\_3\) 
            e\_2, \(e\_3\) e\_3}}\)\)\)], "Input",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(where\ the\ indicated\ products\ are\ to\ be\ replaced\ by\ their\ \
linear\ values\ for\ a\ specific\), "\n", 
    \(algebra . \ 
        Note\ that\ the\ first\ member\ of\ "\<elements\>"\ is\ always\ taken\
\ as\ the\ identity\), "\n", 
    \(element\ of\ the\ algebra\ regardless\ of\ the\ symbol\ used\ for\ it . \
\ So\ in\ the\ above\ example, \n\(e\_0\) e\_i\  = \ \(\(e\_i\) e\_0\  = \ 
        e\_i\)\ , \ 
    and\ the\ top\ row\ \ and\ left\ column\ of\ the\ matrix\ \ will\ equal \
\(\("\<elements\>"\)\(.\)\)\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    \(The\ algebra\ is\ then\ established\ by\ the\ command\)], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\(\(makealgebra[
        producttable]\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ [8]\)\)\)], "Input",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(which\ sets\ the\ reserved\ variable\ "\<algebra\>"\ to\ producttable . \
\ The\ variable\ "\<algebra\>"\), "\n", 
    \(constitutes\ the\ actual\ look - 
      up\ table\ for\ products\ of\ elements\ during\ calculations . \n
          It\ can\ be\ displayed\ in\ MatrixForm\ by\ typing\ the\ the\ \
\(command : \ mtx[] . \ The\ "\<algebra\>"\ can\)\), "\n", 
    \(be\ changed\ at\ any\ time\ by\ executing\ [
        8]\ with\ a\ different\ \(\(argument\)\(.\)\)\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(The\ AVF\ program\ requires\ an\ "\<identity\>"\ element, 
    acting\ as\ a\ "\<unital\>"\ operator\ \ to\ serve\ \), "\n", 
    \(as\ a\ \ placeholder\ in\ many\ calculations . \ 
        If\ the\ algebra\ defined\ by\ producttable\ does\ not\), "\n", 
    \(include\ an\ identity\ element, 
    one\ must\ be\ supplied\ by\ executing\ the\ command\ \ makealgebra[]\), \
"\n", 
    \(with\ two\ arguments, makealgebra[producttable, symbol], 
    where\ the\ second \((optional)\)\), "\n", 
    \(argument, symbol, 
    will\ be\ used\ as\ a\ new\ first\ member\ of\ "\<elements\>", 
    to\ function\ as\), "\n", 
    \(the\ essential\ placeholder . \ 
        This\ will\ have\ no\ effect\ on\ the\ products\ defined\ by\), "\n", \

    \(producttable, \ 
    nor\ on\ calculations\ with\ AVFs\ not\ involving\ the\ spurious\ \
\(\("\<identity\>"\)\(.\)\)\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(Note\ that\ the\ initial\ \(values : \ elements\) = {identity}, 
    algebra\  = \ {{identity}}\ are\ set\ \), "\n", 
    \(when\ the\ program\ AVF . m\ is\ \ called . \ 
        These\ values\ are\ appropriate\ for\ doing\ ordinary\ \), "\n", 
    \(differential\ form\ \ analysis, 
    and\ so\ for\ this\ purpose\ it\ is\ not\ necessary\ to\ input\ any\ \), \
"\n", 
    \(algebra\ \(\(table\)\(.\)\)\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    RowBox[{
      \(The\ particular\ case\ of\ Clifford\ algebras\ is\ implemented\ in\ 
        the\ CAV\ utility\ program\), " "}], 
  \(described\ below.\ Using\ CAV, 
    setting\ up\ a\ \ Clifford\ algebra\ can\ be\ easily\ accomplished\), 
    RowBox[{
      RowBox[{
      "by", " ", "defining", " ", "a", " ", "list", " ", "containing", " ", 
        "the", " ", "signature", " ", "of", " ", "the", " ", "metric", " ", 
        "in", " ", "an", " ", 
        StyleBox["orthonormal",
          FontVariations->{"Underline"->True}], " ", \(basis.\nMany\), " ", 
        "problems", " ", "in", " ", "metric", " ", "spaces"}], ",", 
      \(for\ example\), ",", \(can\ be\ conveniently\ treated\ with\ the\)}], 
  \(CAV\ orthonormal\ frame\ form, \[Theta]\&^\ , 
    and\ associated\ CAV\ connection\ form, \[Omega]\&^, which\ are\), 
  \(constructed\ by\ the\ CAV\ \(program.\)\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["III. AVF Expressions", "Section",
  PageBreakAbove->True,
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontSize->16,
  FontTracking->"Condensed"],

Cell[BoxData[
    \(\(\(An\ AVF\ expression\ is\ just\ a\ sum\ of\ terms\ similar\ to\ the\ 
      sample\ term\ in\ [1]; e.g., \)\ \)\)], "Input",
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    RowBox[{"                   ", 
      \(avf = 2\ x\^2\ y\ e\_2 + \[Lambda]\ z\ \[Theta]\_2\[Wedge]dx\ e\_0 - 
          \ \(y\^\(-3\)\) \[Theta]\_1\[Wedge]\[Theta]\_4\[Wedge]\[Theta]\_2\ 
            e\_1 + \[Theta]\_3
              \[Wedge]d\[Theta]\_2
                \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \n
              \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ [9]\)}], 
    RowBox[{"                           ", 
      StyleBox[
        \(2\ x\^2\ y\ e\_2 + z\ \[Lambda]\ e\_0\ \[Theta]\_2\[Wedge]dx + 
          \[Theta]\_3\[Wedge]d\[Theta]\_2 - 
          \(e\_1\ \[Theta]\_1\[Wedge]\[Theta]\_4\[Wedge]\[Theta]\_2\)\/y\^3\),
        
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"Underline"->False,
        "Outline"->False,
        "Shadow"->False}]}]}], "Input",
  CellLabel->"In[8]:=",
  Evaluatable->False,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[TextData[{
  "Any symbol in a wedge product must be a member of \"forms\" (which \
automatically\nincludes \"dscalars\"), or of \"dforms\" (which is also \
automatically constructed).\nImproper inputs would include;e.g., ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\[Theta]\_1\),
            "TraditionalForm"], "\[Wedge]", \((\(-\[Theta]\_4\)\)}], 
        TraditionalForm]]],
  ") , (z ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(\[Theta]\_2\),
              "TraditionalForm"], ")"}], "\[Wedge]", " ", "dx"}], 
        TraditionalForm]]],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_3\)]],
  "\[Wedge] d ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_2\)]],
  " , y ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            FormBox[\(e\_2\),
              "TraditionalForm"], \(e\_3\)}],
          FontSize->14], TraditionalForm]]],
  ".\nNote that AVF expressions can be of inhomogeneous degree as \
differential forms.\n\nSince the symbol \[Lambda] is not a member of any \
list, it would be treated as a constant\nscalar. The missing algebra-element \
of the last input term defaults to the\nidentity element of the algebra (the \
first member of \"elements\"). Thus, the\nalgebra-element could also have \
been omitted in the second term. If the algebra-\nelement were omitted from \
all terms, \"avf\" would become an ordinary differential\nform expression."
}], "Input",
  PageBreakBelow->Automatic,
  FormatType->TextForm,
  FontFamily->"Courier",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["IIIa. Input", "Subsection",
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontSize->12,
  FontTracking->"Condensed"],

Cell["\<\
The expression \"avf\" could be typed in from the keyboard just as \
it appears 
in [9]. For longer expressions, or more complicated symbols, this can become
sufficiently tedious that defining a symbol palette may be useful, although
the BasicInput palette is usually sufficient. In the case of expressions
with uniform structure, Mathematica's Sum function can be used, either with
indexed symbols, or with part specifications in the lists of variables; e.g.,\
\
\>", "Input",
  PageBreakBelow->Automatic,
  FormatType->TextForm,
  FontFamily->"Courier",
  FontWeight->"Plain"],

Cell[BoxData[{
    RowBox[{"\t\t\t\t ", \(avf1 = Sum[\(\[Theta]\_i\) e\_i, {i, 3}]\)}], "\n",
   
    RowBox[{"                                                         ", 
      StyleBox[\(e\_1\ \[Theta]\_1 + e\_2\ \[Theta]\_2 + e\_3\ \[Theta]\_3\),
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"Underline"->False,
        "Outline"->False,
        "Shadow"->False}]}], "\n", 
    RowBox[{
      "                                                                       \
                                                                              \
                           ", \([10]\)}], "\n", 
    RowBox[{
      "\t\t\t\t ", \(avf1 = 
        Sum[forms[\([i]\)]\ elements[\([i + 1]\)], {i, 3}]\)}], "\n", 
    RowBox[{"                                                         ", 
      StyleBox[\(e\_1\ \[Theta]\_1 + e\_2\ \[Theta]\_2 + e\_3\ \[Theta]\_3\),
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"Underline"->False,
        "Outline"->False,
        "Shadow"->False}]}]}], "Input",
  CellLabel->"In[10]:=",
  Evaluatable->False,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell["\<\
Whenever an AVF expression is used as an argument in an AVF \
function (such as
multiplication), it is converted to an equivalent List expression adapted to 
the simplified structure of AVFs. The purpose is to allow writing efficient \
AVF
procedures and to accomplish certain operations that are quite difficult to
implement with the standard commands provided by Mathematica.

These conversions happen \"behind the scenes\" and are generally invisible. \
The
function \"in[avf]\" creates the equivalent List expression for the argument \
\"avf\"
whenever it is required in a calculation. The List expression can be \
displayed
by executing that command with any AVF argument. Caution: only a properly \
input
\"avf\" will be converted correctly.\
\>", "Input",
  PageBreakBelow->Automatic,
  FormatType->TextForm,
  FontFamily->"Courier",
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IIIb. Output", "Subsection",
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontSize->12,
  FontTracking->"Condensed"],

Cell["\<\

Upon completion of an AVF procedure, the final List expression is converted \
back
to standard algebraic format by the function \"out[final]\", essentially the
inverse of \"in\", except that all monomial wedge products are re-arranged \
into
canonical Mathematica order and the identity element of the algebra is \
suppressed.
Any of the usual Mathematica commands can then be used on the output \
expression.
\
\>", "Input",
  PageBreakBelow->Automatic,
  FormatType->TextForm,
  FontFamily->"Courier",
  FontWeight->"Plain"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["IV. Algebraic Operations", "Section",
  PageBreakAbove->True,
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontSize->16,
  FontTracking->"Condensed"],

Cell[BoxData[{
    \(\(There\ are\ three\ special\ algebraic\ functions\ on\ AVFs\ \
implemented\ in\ the\ program;\)\), "\n", 
    \(multiplication, factoring\ out\ a\ basis\ form, 
    and\ contraction\ with\ \(\(vectors\)\(.\)\)\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["\<\
IVa. Multiplication
\
\>", "Subsection",
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontSize->12,
  FontTracking->"Condensed"],

Cell[BoxData[{
    \(The\ function, \ mult[avf1, avf2], \ 
    gives\ the\ expanded\ product\ of\ two\ AVFs.\ For\ each\ term\), 
    \(in\ the\ result, 
    it\ simultaneously\ performs\ the\ usual\ product\ of\ the\ scalar\ 
      coefficients, the\ exterior\ product\ of\ the\ basis\ forms, \ 
    and\ the\ algebraic\ product\ of\ the\ elements\ as\), 
    \(determined\ by\ the\ "\<algebra\>"\ table.\n\t\t\nThe\ same\ product\ 
      results\ from\ using\ the\ NonCommutativeMultiply\ infix\ operator, 
    \(**\(.\ In\)\)\), 
    \(this\ form, 
    any\ number\ of\ AVFs\ can\ be\ multiplied\ together\ at\ once; \ e.g., 
    \)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\(\t\t\t\)\(avf1 ** avf2 ** 
      avf3 ** \((\(etc\)\(.\))\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ [11]\)\)\)], "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(If\ the\ algebra\ table\ defines\ a\ non - associative\ algebra, 
    it\ may\ be\ necessary\ to\ use\ the\), "\n", 
    \(appropriate\ parentheses\ to\ define\ the\ order\ of\ multiplications . \
\ Without\ parentheses, \nmultiplication\ proceeds\ from\ right\ to\ left, 
    as\ for\ composite\ functions . \n\n
        The\ infix\ wedge\ symbol, \(\[Wedge]\(\(,\)\(\ \
\)\(appearing\ \ between\ basis\ forms\ in\ input\ and\ output\)\)\)\), "\n", \

    \(expressions, \ 
    has\ the\ usual\ significance\ of\ exterior\ product . \ 
        It\ is\ important\), "\n", 
    \(to\ note, however, 
    that\ it\ is\ neither\ recognized\ nor\ used\ by\ the\ program\ \ as\ an\ \
operator . \n
          It\ is\ used\ purely\ symbolically\ to\ denote\ products\ of\ basis\
\ forms\  - \ \ and\ also\ serves\ to\), "\n", 
    \(\(\(prevent\)\(\ \)\(Mathematica\)\(\ \)\(from\)\(\ \)\(incorrectly\)\(\
\ \)\(permuting\)\(\ \)\(the\)\(\ \)\(order\)\(\ \)\(of\)\(\ \)\(such\)\(\ \)\
\(\(products\)\(.\)\)\(\t\)\)\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(Any\ wedge\ symbol\ in\ a\ properly\ input\ AVF\ can\ be\ replaced\ by\ 
      the\ **\ operator.\ This\ has\), 
    \(little\ effect\ when\ the\ wedge\ is\ between\ basis\ forms, 
    but\ in\ the\ case\ of\ non - basis - form\), 
    \(factors 
      \((which\ must\ themselves\ be\ properly\ input\ AVFs\ in\ \ 
          parentheses)\), it\ will\ cause\), 
    \(the\ product\ to\ be\ expanded\ \(out.\)\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(\ The\ AVF\ function, "\<expand[avf]\>", \ 
    is\ included\ for\ just\ this\ purpose.\ It\ substitutes\ **\nfor\ all\ 
      wedge\ symbols\ in\ the\ argument\ "\<avf\>", \ 
    and\ returns\ the\ expanded\ result.\ Its\), 
    \(primary\ use\ is\ to\ facilitate\ replacements\ within\ wedge\ 
      \(products.\)\n\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IVb. Factoring", "Subsection",
  PageBreakAbove->True,
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontSize->12,
  FontTracking->"Condensed"],

Cell[BoxData[{
    RowBox[{\(The\ function\), ",", " ", \(factor[basisform, avf]\), ",", 
      " ", \(returns\ the\ factor\ of\ "\<basisform\>"\ in\ "\<avf\>"\), ",", 
      "\n", \(where\ "\<basisform\>"\ is\ any\ member\ of\ "\<forms\>"\ or\ "\
\<dforms\>"\), ",", " ", 
      RowBox[{
        RowBox[{
        "and", " ", "\"\<avf\>\"", " ", "is", " ", "an", " ", "AVF", 
          " ", \(expression . \nThe\), "\"\<factor\>\"", " ", "function", " ",
           "does", " ", "not", " ", "require", " ", "\"\<basisform\>\"", " ", 
          "to", " ", "factor", " ", 
          StyleBox["all",
            FontVariations->{"Underline"->True}], " ", "of", " ", 
          "\"\<avf\>\""}], ";", \(it\ treats\)}]}], "\n", 
    RowBox[{\(the\ terms\ separately\ and\ returns\ the\ factor\ of\ \
"\<basisform\>"\ in\ whatever\ subset\ of\ terms\), 
      " "}], "\n", \(\(contains\ it . \ 
        For\ the\ sample\ "\<avf\>"\ given\ in\ [
        9]\)\(,\)\(for\ instance\)\(,\)\(\ \)\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\(\(factor[\[Theta]\_2, 
        avf]\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ [
      12]\)\)\)], "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(returns\ \)\)], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    RowBox[{"                                                            ", 
      RowBox[{
        StyleBox[\(dx\ z\ \[Lambda]\),
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], 
        StyleBox["-",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], 
        RowBox[{
          StyleBox[\(\(e\_1\ \[Theta]\_1\[Wedge]\[Theta]\_4\)\/y\^3\),
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          
          StyleBox[
            "                                                                 \
                ",
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox["[",
            FontWeight->"Bold",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox["13",
            FontWeight->"Bold",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}], 
          StyleBox["]",
            FontWeight->"Bold",
            FontSlant->"Plain",
            FontTracking->"Plain",
            FontVariations->{"Underline"->False,
            "Outline"->False,
            "Shadow"->False}]}]}]}]], "Input",
  CellLabel->"In[9]:=",
  Evaluatable->False,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(where\ in\ standard\ AVF\ output\ the\ element\ e\_0\ has\ been\ \
suppressed . \((The\ basisform\ is\ always\n
            factored\ to\ the\ left\ of\ avf)\) . \ 
        While\ this\ function\ may\ not\ be\ used\ very\ often, 
    it\ is\), "\n", 
    \(provided\ because\ it\ is\ \ not\ easily\ \ accomplished\ using\ \
standard\ Mathematica\ operations\), "\n", 
    \(on\ wedge\ \(\(products\)\(.\)\)\), "\n", 
    \(\t\t\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["IVc. Vector Contraction", "Subsection",
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontSize->12,
  FontTracking->"Condensed"],

Cell[BoxData[{
    \(In\ this\ program, \ a\ vector\ is\ a\ list\ of\ components, \ 
    each\ component\ representing\), "\n", 
    \(its\ contraction\ on\ the\ corresponding\ member\ of "\<forms\>"\ \
\((which\ includes\ "\<dscalars\>")\) . \nIn\ effect, 
    the\ vector\ is\ expressed\ in\ the\ dual\ basis\ to\ "\<forms\>" . \ 
        For\ convenience, \n
    the\ procedure "\<makevectors[]\>" \((no\ arguments)\) 
      will\ generate\ four\ such\ vectors, \n\((vec1, vec2, vec3, vec4)\) . \ 
        Each\ of\ these\ is\ a\ list\ of\ the\ same\ length\ as\ "\<forms\>", \
\nhaving\ indexed\ components, \((v1\_i, v2\_i, v3\_i, v4\_i)\), 
    to\ represent\ its\ contraction\ on\), "\n", 
    \(the\ \ ith\ \ member\ of\ "\<forms\>" . \ 
        If\ needed\ \ more\ vectors\ are\ easily\ \
\(\(constructed\)\(.\)\)\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(Neither\ the\ names\ of\ the\ vectors\ nor\ the\ component\ symbols\ are
      \ reserved, \ so\ they\), 
    \(can\ be\ given\ any\ \ variable\ names\ at\ will.\ A\ vector\ component
      \ should\ be\ defined\ for\), 
    \(each\ member\ of\ "\<forms\>", however, 
    unless\ care\ is\ taken\ to\ avoid\ potential\ errors.\ \nWhenever\ 
      "\<makeforms\>"\ is\ executed, 
    it\ calls\ the\ "\<makevectors\>"\ routine\ automatically\ \), 
    \(to\ create\ four\ new\ vectors\ agreeing\ in\ length\ and\ order\ with\ 
      the\ new\ "\<forms\>"\ \(list.\)\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(Additional\ structures\ are\ necessary\ to\ implement\ the\ contraction\
\ of\ vectors\ on\ the\), "\n", 
    \(2 - 
      forms\ included\ in\ "\<dforms\>" . \ 
          This\ is\ accomplished\ by\ defining\ a\ list\ of\ replacements\), \
"\n", 
    \(named "\<drules\>" 
      to\ express\ "\<dforms\>"\ in\ terms\ of\ "\<forms\>" . \ 
        The\ reserved\ variable "\<drules\>"\), "\n", 
    \(can\ be\ established\ in\ the\ standard\ way\ \
by\ \ "\<makedrules[replacement_list]\>" . \nFor\ instance, 
    a\ typical\ set\ of\ "\<drules\>"\ might\ \(\(be\)\(:\)\)\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    RowBox[{
      "\t\t", \(makedrules[{d\[Theta]\_1 -> \[Theta]\_2\[Wedge]\[Theta]\_3, 
          d\[Theta]\_2 -> \[Theta]\_3\[Wedge]\[Theta]\_1, 
          d\[Theta]\_3 -> \[Theta]\_1\[Wedge]\[Theta]\_2}]\)}], "\n", 
    RowBox[{
      "                                                                       \
                                                                              \
                                ", \([14]\)}], "\n", 
    RowBox[{"                                         ", 
      StyleBox[\({d\[Theta]\_1 \[Rule] \[Theta]\_2\[Wedge]\[Theta]\_3, 
          d\[Theta]\_2 \[Rule] \[Theta]\_3\[Wedge]\[Theta]\_1, 
          d\[Theta]\_3 \[Rule] \[Theta]\_1\[Wedge]\[Theta]\_2}\),
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"Underline"->False,
        "Outline"->False,
        "Shadow"->False}], "       "}]}], "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[{\(The\ initial\ default\ value\ for\ "\<drules\>"\ is\ \
"\<natural\>", {d\[Theta]\_1 -> 0, etc}, 
    i . e . \ 
      specifying\), "\n", \(that\ all\ members\ of\ "\<forms\>"\ are\ closed \
. \ The\ "\<drules\>"\ are\ invoked\ automatically\ for\), "\n", 
    RowBox[{\(contractions\ where\ they\ are\ essential\), ",", 
      RowBox[{"but", " ", 
        StyleBox["only",
          FontVariations->{"Underline"->True}], " ", \(then . \ The\), " ", 
        "\"\<drules\>\"", " ", "are", " ", "an", " ", 
        "extremely"}]}], "\n", \(important\ and\ useful\ feature\ of\ AVF\ \
for\ many\ other\ purposes\ in\ addition\ to\ contraction . \n\ 
        How\ the\ "\<drules\>"\ are\ applied\ is\ illustrated\ in\ detail\ in\
\ the\ demonstration\ \(\(programs\)\(.\)\)\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    RowBox[{
    \(Note\ that\ the\ vector\ components\), ",", 
      \((v1\_i, v2\_i, v3\_i, v4\_i)\), ",", " ", 
      RowBox[{"are", " ", 
        StyleBox["not",
          FontVariations->{"Underline"->True}], " ", "automatically", " ", 
        "introduced"}]}], 
  \(into\ the "\<scalars\>"\ list, \ 
    and\ so\ will\ not\ be\ differentiated.\ They\ can\ be\ added\ in\ by; \n
    e.g., \)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\(\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\(\(makescalars[
        Join[scalars, 
          vec1]]\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ [15]\)\)\)], "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(so\ that\ the\ \(v1\_i\) 
      become\ independent\ scalars\ with\ their\ own\ exterior\ \
derivatives\ \ \ dv1\_i . \nAlternatively, \ 
    the\ components\ could\ be\ given\ assigned\ values\ either\ as\ \
explicit, \nor\ unspecified, 
    functions\ of\ the\ existing\ scalars . \ This\ should\ not\ be\ done, \n
    if\ they\ have\ been\ introduced\ as\ independent\ scalars\ by\ the\ \
"\<makescalars\>"\ \(\(command\)\(.\)\(\n\)\(\t\t\)\)\)], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell["\<\
The function,contract[vector,expression],returns the contraction of \
\"vector\" on
\"expression\",where \"expression\" can be either a single AVF,or a list of \
AVFs. This operation also has an infix form using the \"small-circle\" \
symbol,which is input
by typing the sequence;(esc,s,c,esc). And in this form,multiple contractions \
can
be performed;e.g.,\
\>", "Input",
  CellLabel->"In[9]:=",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\(\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\(vec1\
\[SmallCircle]vec2\[SmallCircle]vec3\[SmallCircle]
      avf1\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ [
        16]\)\)\)], "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(or\ for\ a\ list\ of\ AVFs, \)\)], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\(\t\t\t\ \ \)\(vec4\[SmallCircle]
      vec1\[SmallCircle]{avf1, avf2, 
          avf3}\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ [17]\)\)\)], "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["V. Exterior Differentiation", "Section",
  PageBreakAbove->True,
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontSize->16,
  FontTracking->"Condensed"],

Cell[BoxData[{
    \(The\ operator, \ 
    d[expression], \ \(\(returns\)\(\ \)\(the\)\(\ \)\(exterior\)\(\ \
\)\(derivative\)\(\ \)\(of\)\(\ \)\("\<expression\>"\)\(\ \)\(which\)\(\ \)\)\
\), "\n", 
    \(may\ be\ either\ a\ single\ AVF, 
    or\ a\ list\ of\ AVFs . \ 
        The\ symbols\ used\ for\ the\ derivatives\ of\ all\), "\n", 
    \(the\ fundamental\ variables\ are\ in\ "\<dscalars\>" 
      and\ "\<dforms\>" . \ Their\ "\<make\>"\ commands\ also\), "\n", 
    \(establish\ two\ additional\ replacement\ lists, "\<sderiv\>"\ and\ \
"\<fderiv\>", to\ accomplish\ the\), "\n", 
    \(derivations . \n\t\nA\ very\ simple\ example, 
    for\ an\ ordinary\ \ 1 - form, f, 
    is\ shown\ \(\(here\)\(:\)\)\)}], "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    RowBox[{
      "\t\t\t\t           ", \(f = 
        x\ \[Theta]\_1 + y\ \[Theta]\_2 + z\ \[Theta]\_3\)}], "\n", 
    RowBox[{"                                                            ", 
      StyleBox[\(x\ \[Theta]\_1 + y\ \[Theta]\_2 + z\ \[Theta]\_3\),
        FontWeight->"Plain",
        FontSlant->"Plain",
        FontTracking->"Plain",
        FontVariations->{"Underline"->False,
        "Outline"->False,
        "Shadow"->False}]}], "\n", 
    RowBox[{
      "                                                     ", \(\(d[
          f]\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\[NonBreakingSpace]\[NonBreakingSpace]\[NonBreakingSpace]\[NonBreakingSpace]\
\[NonBreakingSpace]\[NonBreakingSpace]\[NonBreakingSpace]\[NonBreakingSpace]\
\[NonBreakingSpace]\[NonBreakingSpace]\[NonBreakingSpace]\[NonBreakingSpace]\
\[NonBreakingSpace]\[NonBreakingSpace]\[NonBreakingSpace]\[NonBreakingSpace]\
\[NonBreakingSpace]\[NonBreakingSpace]\[NonBreakingSpace]\[NonBreakingSpace]\
\[NonBreakingSpace]\[NonBreakingSpace]\[NonBreakingSpace]\[NonBreakingSpace]\
\[NonBreakingSpace]\[NonBreakingSpace]\[NonBreakingSpace]\[NonBreakingSpace]\
\[NonBreakingSpace]\[NonBreakingSpace]\[NonBreakingSpace]\[NonBreakingSpace]\
\[NonBreakingSpace]\[NonBreakingSpace]\ \ \[NonBreakingSpace][
        18]\)}], "\[IndentingNewLine]", 
    RowBox[{"                                                            ", 
      RowBox[{
        StyleBox[\(x\ d\[Theta]\_1\),
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], 
        StyleBox["+",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], 
        StyleBox[\(y\ d\[Theta]\_2\),
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], 
        StyleBox["+",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], 
        StyleBox[\(z\ d\[Theta]\_3\),
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], 
        StyleBox["+",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], 
        StyleBox[\(dx\[Wedge]\[Theta]\_1\),
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], 
        StyleBox["+",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], 
        StyleBox[\(dy\[Wedge]\[Theta]\_2\),
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}], "+", " ", 
        StyleBox[\(dz\[Wedge]\[Theta]\_3\),
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False}]}]}]}], "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(\nThe\ Lie\ derivative\ of\ AVFs\ is\ \ defined\ by\ the\ 
      \(expansion : \)\)\)], "Input",
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \t\ \)\(lie[vec, avf] := 
      vec\[SmallCircle]d[avf] + \(d[
            vec\[SmallCircle]
              avf]\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ [19]\)\)\)], "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(and\ since\ both\ \ d[]\ and\ \[SmallCircle]\ work\ with\ \ AVF\ lists, 
    the "\<avf\>" argument\ here\ can\ be\ a\ list\ of\ AVFs.\nAs\ explained\ 
      in\ the\ section\ on\ contractions, 
    to\ execute\ this\ function\ on\ general\ objects, \n
    a\ set\ of\ "\<drules\>" must\ be\ defined, 
    and\ in\ order\ to\ be\ differentiated, the\ vector\ components\), 
    \(must\ either\ be\ members\ of\ "\<scalars\>" themselves, 
    or\ expressed\ in\ terms\ of\ "\<scalars\>".\n\t\t\nMany\ examples\ of\ 
      these\ operations\ are\ given\ in\ the\ demonstration\ 
      \(programs.\)\)}], "Input",
  PageBreakBelow->Automatic,
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["VI. The CAV Program", "Section",
  PageBreakAbove->True,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontSize->16,
  FontTracking->"Condensed"],

Cell[BoxData[{
    \(CAV\ is\ a\ utility\ program\ to\ facilitate\ setting\ up\ Clifford - 
      Algebra - Valued\ forms\), "\n", 
    \(within\ AVF . \ It\ \ is\ accessed\ by\ executing\ the\ \(command : \ 
        makeclifford[{signature_list}] . \n
            The\ argument\ specifies\ the\ signatures\ of\ the\ diagonal\ \
metric\), \ g\_ij, for\ a\ Clifford\ algebra\), "\n", 
    \(\(\(defined\ with\ respect\ to\ \ an\ \ orthonormal\ basis\)\(,\)\(\
\[Gamma]\_i\ ; i . e . \)\(,\)\(\ \ \)\)\)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\(\t\)\(\(\[Gamma]\_i\) \[Gamma]\_j + \(\[Gamma]\_j\) \[Gamma]\_i = 
      2\ \(g\_ij\) \[Gamma]\_0\ \ \ \ \ \ \ \ \((\ 
          g\_ij = 0\ {i \[NotEqual] j}, 
          g\_ii = \(\[PlusMinus]1\))\)\ \ \ \ \ \ \((1 \[LessEqual] {i, 
                j} \[LessEqual] cadim)\)\ \ \ \ \ \ \ \ \ [20]\)\)\)], "Input",\

  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(where\ \(\[Gamma]\_0\) 
      is\ the\ identity\ \ element\ and\ "\<cadim\>"\ is\ the\ number\ of\ \
generators . \ For\ example, \ 
    a\ \ 4 - dim\ \ Clifford\ algebra\ with\ Lorentzian\ metric\ would\ be\ \
obtained\ \(\(by\)\(:\)\)\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\(\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\(\(makeclifford[{1, 1, 
          1, \(-1\)}]\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ [21]\)\)\)], "Input",
  CellLabel->"In[6]:=",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(Another\ option\ would\ \(be : \)\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\(\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\(\(makeclifford[{\(-1\), \(-1\), \(-1\), 
          1}]\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ [
      22]\)\)\)], "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(but\ the\ two\ options\ actually\ give\ different\ Clifford\ algebras . \
\ The\ input\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\(\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\ \ \ \ \ \ \ \ \t\ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\(\(makeclifford[{\(-1\), \
\(-1\)}]\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ [
      23]\)\)\)], "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(gives\ a\ Clifford\ algebra\ which\ is\ isomorphic\ to\ the\ algebra\ of
      \ \(quaternions.\)\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["VIa. Fundamental Lists in CAV", "Subsection",
  PageBreakAbove->True,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontSize->12,
  FontTracking->"Condensed"],

Cell[BoxData[{
    \(The\ "\<makeclifford[]\>"\ command\ defines\ all\ the\ fundamental\ AVF\
\ lists\ for\ the\ chosen\ \), "\n", 
    \(Clifford\ algebra, 
    with\ the\ exception\ of\ "\<scalars\>"\ which\ remains\ the\ null\ list \
\(\({}\)\(.\)\)\)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(The\ program\ first\ checks\ the\ variable\ "\<clifflist\>" 
      to\ see\ if\ this\ algebra\ has\ been\ \), "\n", 
    \(encountered\ previously; \ 
    if\ so, \ \(\(it\)\(\ \)\(will\)\(\ \)\(input\)\(\ \)\(the\)\(\ \
\)\(appropriate\)\(\ \)\(data\)\(\ \)\(file\)\(\ \)\(from\)\(\ \)\(the\)\(\ \
\)\)\), "\n", 
    \("\<CliffordAlgebras\>"\ folder . \ If\ not, 
    it\ will\ proceed\ to\ construct\ the\ necessary\), "\n", 
    \(quantities, 
    save\ them\ in\ a\ file\ in\ that\ folder, \ \(\(and\)\(\ \)\(add\)\(\ \)\
\(the\)\(\ \)\(respective\)\(\ \)\(filename\)\(\ \)\)\), "\n", 
    \(to\ "\<clifflist\>", 
    so\ it\ won' 
      t\ be\ necessary\ to\ repeat\ the\ calculation . \ Since\ the\), "\n", 
    \("\<algebra\>"\ matrix\ \ contains\ 2^\((2\ cadim)\)\ entries, 
    it\ is\ expensive\ in\ both\ time\ and\), "\n", 
    \(memory\ to\ calculate\ for\ cadim > 
      6  although\ the\ program\ is\ capable\ of\ cadim \[LessEqual] 
      11. \)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(If\ the\ command\ in\ [21]\ or\ [22] above\ were\ executed, \ 
    the\ "\<elements\>"\ list\ for\ either\ one\ \), 
    \(would\ appear\ \(as : \)\)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    \({\[Gamma]\_0, \[Gamma]\_1, \[Gamma]\_2, \[Gamma]\_3, \[Gamma]\_4, \
\[Gamma]\_12, \[Gamma]\_13, \[Gamma]\_14, \[Gamma]\_23, \[Gamma]\_24, \
\[Gamma]\_34, \[Gamma]\_15, \[Gamma]\_25, \[Gamma]\_35, \[Gamma]\_45, \
\[Gamma]\_5}\ \ \ \ \ \ \ \ \ \ \ \ [24]\)], "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(although\ the\ "\<algebra\>"\ tables\ would\ differ . \ 
        Multiple\ indices\ indicate\ the\ \), "\n", 
    \(corresponding\ products; 
    e . g . , \[Gamma]\_23 = \(\[Gamma]\_2\) \[Gamma]\_3 . \ 
          The\ element\ \(\[Gamma]\_\(1\  + \ cadim\)\) 
        is\ always\ used\ to\ \), "\n", 
    \(represent\ the\ complete\ product\ element; \ 
    in\ this\ case, \ \[Gamma]\_5 = \(\[Gamma]\_1\) \(\[Gamma]\_2\) \
\(\[Gamma]\_3\) \[Gamma]\_4 . \ And\ in\ order\ \), "\n", 
    \(to\ minimize\ the\ amount\ of\ indices, \ 
    a\ "\<dual\>"\ representation\ for\ higher\ products\ is\), "\n", 
    \(employed; 
    i . e . , \[Gamma]\_15 = \(\(\[Gamma]\_1\) \[Gamma]\_5 = 
        sig[1] \[Gamma]\_234\), \(\(etc\)\(.\)\)\)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["VIb. Variables and Algebra-Valued-Forms", "Subsection",
  PageBreakAbove->True,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontSize->12,
  FontTracking->"Condensed"],

Cell[BoxData[
    \(Two\ lists\ of\ graded\ symbols\ are\ generated\ by\ 
      \("\<makeclifford[]\>" : \ 
        "\<omegas\>"\ and\ "\<thetas\>".\ \nBoth\ are\ established\ as\ basis
            \ 1 - forms\ by\ "\<makeforms\>"\); e.g., 
    \((in\ the\ cadim\  = 4\ \ case)\)\)], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\(\ \)\(forms = {\[Theta]\&0, \[Theta]\&1\_1, \[Theta]\&1\_2, \
\[Theta]\&1\_3, \[Theta]\&1\_4, \[Theta]\&2\_12, \[Theta]\&2\_13, \[Theta]\&2\
\_14, \[Theta]\&2\_23, \[Theta]\&2\_24, \[Theta]\&2\_34, \[Theta]\&3\_1, \
\[Theta]\&3\_2, \[Theta]\&3\_3, \[Theta]\&3\_4, \[Theta]\&4, \n\t\ \ \ \ \ \ \
\ \ \ \ \ \[Omega]\&0, \[Omega]\&1\_1, \[Omega]\&1\_2, \[Omega]\&1\_3, \
\[Omega]\&1\_4, \[Omega]\&2\_12, \[Omega]\&2\_13, \[Omega]\&2\_14, \
\[Omega]\&2\_23, \[Omega]\&2\_24, \[Omega]\&2\_34, \[Omega]\&3\_1, \
\[Omega]\&3\_2, \[Omega]\&3\_3, \[Omega]\&3\_4, \[Omega]\&4\ \ }\ \ \ \ \ \ [
        25]\)\)\)], "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(where\ the\ grades\ of\ the\ basis\ 1 - 
      forms\ are\ indicated\ by\ overscripts . \ These\ are\ used\), "\n", 
    \(to\ create\ two\ graded\ CAV\ \ 1 - 
      forms, \ \(\[Theta]\&^\ \ \ and\ \ \ \[Omega]\&^;\)\)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[Theta]\&^\  = \ \ \[Theta]\&0\ \
\[Gamma]\_0 + \n\t\t\ \ \ \ \ \ \ \[Gamma]\_1\ \[Theta]\&1\_1 + \[Gamma]\_2\ \
\[Theta]\&1\_2 + \[Gamma]\_3\ \[Theta]\&1\_3 + \[Gamma]\_4\ \[Theta]\&1\_4 + \
\n\t\t\ \ \ \ \ \ \ \[Gamma]\_12\ \[Theta]\&2\_12 + \[Gamma]\_13\ \[Theta]\&2\
\_13 + \[Gamma]\_14\ \[Theta]\&2\_14 + \[Gamma]\_23\ \[Theta]\&2\_23 + \
\[Gamma]\_24\ \[Theta]\&2\_24 + \[Gamma]\_34\ \[Theta]\&2\_34 + \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \([26]\)\)\
, "\n", 
    \(\t\t\ \ \ \ \ \ \ \[Gamma]\_15\ \[Theta]\&3\_1 + \[Gamma]\_25\ \[Theta]\
\&3\_2 + \[Gamma]\_35\ \[Theta]\&3\_3 + \[Gamma]\_45\ \[Theta]\&3\_4 + \n\t\t\
\ \ \ \ \ \ \ \[Theta]\&4\ \[Gamma]\_5\n\), "\n", 
    \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[Omega]\&^\  = \ \ \[Omega]\&0\ \
\[Gamma]\_0 + \n\t\t\ \ \ \ \ \ \[Gamma]\_1\ \[Omega]\&1\_1 + \[Gamma]\_2\ \
\[Omega]\&1\_2 + \[Gamma]\_3\ \[Omega]\&1\_3 + \[Gamma]\_4\ \[Omega]\&1\_4 + \
\n\t\t\ \ \ \ \ \ \[Gamma]\_12\ \[Omega]\&2\_12 + \[Gamma]\_13\ \
\[Omega]\&2\_13 + \[Gamma]\_14\ \[Omega]\&2\_14 + \[Gamma]\_23\ \
\[Omega]\&2\_23 + \[Gamma]\_24\ \[Omega]\&2\_24 + \[Gamma]\_34\ \
\[Omega]\&2\_34 + \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \([27]\)\), "\n", 
    \(\t\t\ \ \ \ \ \ \[Gamma]\_15\ \[Omega]\&3\_1 + \[Gamma]\_25\ \
\[Omega]\&3\_2 + \[Gamma]\_35\ \[Omega]\&3\_3 + \[Gamma]\_45\ \[Omega]\&3\_4\ \
 + \n\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[Omega]\&4\ \[Gamma]\_\(\(5\)\(\t\t\
\t\)\)\)}], "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(where\ the\ grades\ have\ been\ put\ on\ separate\ lines\ for\ clarity \
. \ Other\ CAV\ expressions\), "\n", 
    \(with\ higher\ degree\ p - 
      forms \((not\ necessarily\ homogeneous)\)\ can\ also\ be\ defined . \ 
          Examples\), "\n", 
    \(are\ the\ homogeneous\ torsion\ and\ curvature\ 2 - 
      forms\ discussed\ \(\(next\)\(.\)\)\)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(In\ the\ particular\ case\ of\ metric\ \ geometry, \ 
    the\ \ grade[1]\ part\ of\ \[Theta]\&^\ \ could\ represent\), "\n", 
    \(an\ orthonormal\ co - 
      frame\ with\ signature\ given\ by\ the\ Clifford\ algebra, \ 
    and\ the\), "\n", 
    \(grade[2]\ part\ of\ \[Omega]\&^\ \ would\ represent\ Cartan' s\ skew - 
      symmetric\ connection\ matrix . \nThe\ CAV\ commands, \ 
    grade[1, \[Theta]\&^]\ and\ grade[2, \[Omega]\&^] 
      will\ pick\ out\ these\ \(\(parts\)\(:\)\)\)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[Theta]\&^ = \ \
\(grade[1, \[Theta]\&^] = \[Gamma]\_1\ \[Theta]\&1\_1 + \[Gamma]\_2\ \[Theta]\
\&1\_2 + \[Gamma]\_3\ \[Theta]\&1\_3 + \[Gamma]\_4\ \[Theta]\&1\_4\)\ \ \), "\
\n", 
    \(\t\t\t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \([28]\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \), "\n", 
    \(\ \ \ \ \ \ \ \[Omega]\&^ = \ \(grade[
          2, \[Omega]\&^] = \[Gamma]\_12\ \[Omega]\&2\_12 + \[Gamma]\_13\ \
\[Omega]\&2\_13 + \[Gamma]\_14\ \[Omega]\&2\_14 + \[Gamma]\_23\ \
\[Omega]\&2\_23 + \[Gamma]\_24\ \[Omega]\&2\_24 + \(\(\[Gamma]\_34\)\(\ \)\(\
\[Omega]\&2\_34\)\(\ \ \)\(\n\)\(\ \ \ \ \ \ \ \t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \)\)\)\)}], "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(In\ this\ geometric\ situation, \ 
    the\ components\ of\ the\ torsion\ 2 - form, \[CapitalTheta], \ and\ the\ 
    \), 
    \(curvature\ 2 - form, \[CapitalOmega], \ 
    are\ defined\ by\ the\ Cartan\ structure\ \(equations : \)\)}], "Input",
  PageBreakAbove->True,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(\ \ \ \ \ \ \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[CapitalTheta]\_i = 
      d\[Theta]\&1\_i + \[Sum]\+\(k = 1\)\%cadim\( 
                g\_kk\) \[Omega]\&2\_ik\[Wedge]\[Theta]\&1\_k\), "\
\[IndentingNewLine]", 
    \(\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\
\([29]\)\), "\n", 
    \(\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\[CapitalOmega]\_ij = \ 
      d\[Omega]\&2\_ij + \[Sum]\+\(k = 1\)\%cadim\( 
                g\_kk\) \[Omega]\&2\_ik\[Wedge]\[Omega]\&2\_kj\)}], "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(These\ can\ be\ combined\ into\ the\ \ CAV\ torsion\ \ 2 - form, 
    \[CapitalTheta]\&^\  = 
      \[Sum]\+i\%cadim\( \[CapitalTheta]\_i\) \[Gamma]\_i, and\ the\ \ CAV\ 
    \), 
    \(curvature\ \ 2 - form, 
    \[CapitalOmega]\&^\  = 
      \[Sum]\+\(i, j > i\)\%cadim\ \(\[CapitalOmega]\_ij\) \[Gamma]\_ij, 
    \(which\ are\ then\ given\ by\ the\ AVF\ expressions; \)\ \)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \[CapitalTheta]\&^\  = \ 
      d[\[Theta]\&^] + \(1\/2\) \((\[Omega]\&^ ** \[Theta]\&^ + \[Theta]\&^ ** \
\[Omega]\&^)\)\), "\n", 
    \(\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\
\([30]\)\), "\n", 
    \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[CapitalOmega]\&^\  = \ 
      d[\[Omega]\&^] + \(\(1\/2\) \((\[Omega]\&^ ** \[Omega]\&^)\)\(\ \ \ \
\)\)\)}], "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(and\ these\ CAVs\ comprise\ all\ the\ Cartan\ structure\ equations\ for
        \ the\ manifold - which\ \), 
    \(would\ be\ \ Riemannian\ for\ vanishing\ torsion, \ 
    \[CapitalTheta]\&^ = 0.\ \ The\ CAV\ commands, "\<maketorsion[]\>"\ \ \), 
  
    \(and\ "\<makecurvature[]\>", 
    will\ use\ these\ definitions\ to\ evaluate\ them\ explicitly\ for\), 
    \(any\ \ assigned\ \[Theta]\&^\ \ and\ \(\[Omega]\&^\ .\)\t\t\)}], "Input",\

  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(The\ definitions\ [30] can\ also\ be\ used\ in\ the\ general\ case\ when
      \ \[Theta]\&^\ \ and\ \[Omega]\&^\ \ incorporate\ \ \), 
    \(all\ possible\ grades\ for\ the\ algebra.\ In\ this\ situation, \ 
    \[Omega]\&^\ \ can\ be\ interpreted\ as\ a\ \), 
    \(non - 
      Abelian\ \ CAV\ \ gauge\ potential\ and\ \[CapitalOmega]\&^\ \ as\ the\ 
        corresponding\ CAV\ field\ 2 - form.\ Note\), 
    \(that\ the\ field\ \ \[CapitalOmega]\&^\ \ will\ contain\ a\ mixture\ of
      \ the\ different\ grades\ of\ the\ \ CAV\ \ gauge\), 
    \(potential  \[Omega]\&^.\ In\ the\ cadim = 4\ case, for\ instance, 
    interactions\ are\ generated\ among\ \(the : \)\)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(grade[1] : \((\ vector - valued)\), \n
    grade[2] : \((\ tensor - valued)\), \n
    grade[3] : \((\ pseudovector - valued)\), and\ \ \ \), 
    \(grade[4] : 
      \((\ pseudoscalar - valued)\) parts.\n\t\t\t\nThe\ exception\ is\ the\ 
        \(grade[0] : \((scalar - valued, or\ Abelian)\) part\), 
    which\ never\ \(mixes.\)\n\t\t\n\t\t\t\)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(Both\ the\ torsion\ and\ curvature\ 2 - 
      forms\ satisfy\ \ differential\ identities\ by\ virtue\ of\), 
    \(\(their\ definitions, \)\)}], "Input",
  PageBreakAbove->True,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(\ torsionidentity[] := \((d[\[CapitalTheta]\&^] + \(1\/2\) \
\((\[Omega]\&^ ** \[CapitalTheta]\&^ - \[CapitalTheta]\&^ ** \[Omega]\&^)\) + \
\(1\/2\) \((\[Theta]\&^ ** \[CapitalOmega]\&^ - \[CapitalOmega]\&^ ** \
\[Theta]\&^)\))\) == 0\), "\n", 
    \(\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\
\([31]\)\), "\n", 
    \(\ \ \ \ \ \ \ \ \ \ \ \ curvatureidentity[] := \((d[\[CapitalOmega]\&^] \
+ \(1\/2\) \((\[Omega]\&^ ** \[CapitalOmega]\&^ - \[CapitalOmega]\&^ ** \
\[Omega]\&^)\))\) == 0\)}], "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(and\ are\ known\ to\ the\ program\ by\ these\ names.\ They\ can\ be\ 
      verified\ by\ explicit\), 
    \(calculation, 
    although\ in\ the\ completely\ general\ case\ with\ arbitrary\ basis\ 
      forms\ \), 
    \(and\ all\ grades\ included, it\ requires\ some\ time\ for\ a\ 4 - dim, 
    or\ higher, \ \(algebra.\)\)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(In\ the\ 4 - dim\ \ Riemannian\ case\ with\ \ \[CapitalTheta]\&^ = 0, 
    only\ the\ last\ commutator\ in\ "\<torsionidentity\>"\), "\n", 
    \(survives . \ It\ is\ a\ \ grade[1]\ \ 3 - 
      form\ which\ expresses\ the\ usual\ cyclic\ identity\ for\ the\), "\n", \

    \(curvature\ components . \ The\ corresponding\ anticommutator, 
    G\&^ = \((\[Theta]\&^ ** \[CapitalOmega]\&^ + \[CapitalOmega]\&^ ** \
\[Theta]\&^)\)/2\ , \ \ is\ a\), "\n", 
    \(grade[3]\ \ 3 - form\ \ which\ incorporates\ all\ four\ Ricci\ 3 - 
      forms\ expressing\ the\ \ Ricci, \ \ or\), "\n", 
    \(actually\ \ Einstein, 
    curvature\ tensor . \ 
        It\ satisfies\ a\ contracted\ identity\ with\ the\), "\n", 
    \(general\ form\)}], "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(\ contractedidentity[] := 
      \((d[G\&^] + \(1\/2\) \((\[Omega]\&^**G\&^ + G\&^**\[Omega]\&^)\) - 
            \(1\/2\) 
              \((\[CapitalTheta]\&^**\[CapitalOmega]\&^ + 
                  \[CapitalOmega]\&^**\[CapitalTheta]\&^)\))\) == 
        0\ \ \ \ [32]\)\)], "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  Background->GrayLevel[0.900008]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["VII. AVF Variables and Functions", "Section",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontSize->16,
  FontTracking->"Condensed"],

Cell[BoxData[{
    \(All\ AVF\ names\ are\ lower\ case\ to\ distinguish\ them\ from\ \
Mathematica\ names . \ Most\ of\ the\), "\n", 
    \(names\ on\ these\ lists\ are\ protected\ and\ so\ will\ refuse\ \
assignment . \ A\ large\ number\ of\ \), "\n", 
    \(unlisted\ temporary\ variables\ and\ subroutines\ have\ names\ \
beginning\ with\ \ "\<av$\>" . \ \ To\), "\n", 
    \(avoid\ interference, 
    this\ pattern\ should\ not\ be\ used\ when\ defining\ new\ names\ or\ \
\(\(symbols\)\(.\)\)\)}], "Input",
  PageBreakAbove->False,
  PageBreakWithin->False,
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["VIIa. Variables", "Subsection",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->Automatic,
  FontFamily->"Courier",
  FontSize->12,
  FontTracking->"Condensed"],

Cell[BoxData[{
    \(\ \ 1. \ \ adjlist\  - \ \(\(arbitrary\)\(\ \)\(permutation\)\(\ \)\(of\
\)\(\ \)\(the\)\(\ \)\(list\)\(\ \)\(in\)\(\ \)\("\<elements\>"\)\(\ \ \
\)\)\), "\n", 
    \(\ \ 2. \ \ algebra\  - \ 
      multiplication\ table\ for\ the\ "\<elements\>"\ of\ an\ \ algebra\), "\
\n", 
    \(\ \ 3. \ \ brackets\  - \ Lie\ brackets, \([\ V\_\(forms[\([i]\)]\), 
      V\_\(forms[\([j]\)]\)\ ]\), for\ non - exact\ dual\ vectors\), "\n", 
    \(\ \ 4. \ \ cadim\  - \ number\ of\ generators \((\ \[Gamma]\_i)\), 
    in\ the\ orthonormal\ basis\ of\ a\ Clifford\ algebra\), "\n", 
    \(\ \ 5. \ \ clifflist\  - 
      list\ of\ the\ filenames\ in\ the "\<CliffordAlgebras\>"\ folder\), "\n\
", 
    \(\ \ 6. \ \ coords - \ 
      list\ of\ scalars\ designated\ as\ independent\ variables\), "\n", 
    \(\ \ \(7. \ \ coordsdim\  - \ 
          number\ of\ independent\ variables;\)\  = \ 
      Length[coords]\), "\n", 
    \(\ \ 8. \ \ cosub\  - \ the\ list\ of\ basis\ 1 - 
      forms\ to\ be\ annulled\ in\ a\ subspace; "\<subspace[cosub]\>"\), "\n\
", 
    \(\ \ 9. \ \ depend\  - \ "\<coords\>"\ as\ a\ Sequence; \ 
    used\ for\ function\ arguments\), "\n", 
    \(10. \ \ dforms\  - 
      list\ of\ symbols\ for\ the\ exterior\ derivatives\ of\ the\ members\ \
of\ "\<forms\>"\), "\n", 
    \(11. \ drules\  - \ 
      list\ of\ replacement\ rules\ for\ the\ exterior\ derivatives\ of\ \
"\<forms\>"\), "\n", 
    \(12. \ dscalars\  - \ 
      list\ of\ symbols\ for\ the\ exterior\ derivatives\ of\ \
"\<scalars\>"\), "\n", 
    \(\(13. \ eldim\  - \ number\ of\ algebra\ elements;\)\  = \ 
      Length[elements]\), "\n", 
    \(14. \ elements\  - \ 
      list\ of\ generators\ of\ the\ algebra\ specified\ by\ "\<algebra\>"\), \
"\n", 
    \(15. \ fderiv\  - \ 
      basic\ rules\ to\ give\ exterior\ derivatives\ of\ "\<forms\>"\ and\ \
"\<dforms\>"\), "\n", 
    \(\(16. \ fmdim\  - \ number\ of\ independent\ basis\ 1 - forms;\)\  = \ 
      Length[forms]\), "\n", 
    \(17. \ forms\  - \ list\ of\ basis\ 1 - 
      forms\ generating\ the\ exterior\ algebra\  - 
      includes\ "\<dscalars\>"\), "\n", 
    \(18. \ frame\  - \ list\ of\ orthonormal\ basis\ forms\), "\n", 
    \(\(19. \ frdim\  - \ number\ of\ orthonormal\ basis\ 1 - forms;\)\  = \ 
      Length[frame]\), "\n", 
    \(20. \ gammas\  - all\ \ Clifford\ "\<elements\>", 
    retrieved\ from\ a\ file\ in\ \ "\<CliffordAlgebras\>"\), "\n", 
    \(21. \ identity\  - \ 
        elements = {identity}\ is\ the\ initial\ default\ assignment\ for\ \
"\<elements\>"\), "\n", 
    \(22. \ names\  - \ 
      list\ of\ all\ AVF\ and\ CAV\ variables\ and\ functions\), "\n", 
    \(23. \ natural\  - \ 
      the "\<drules\>" specifying\ "\<closed\>"\ \ basis\ 1 - 
      forms \((\ default\ value)\)\ \), "\n", 
    \(24. \ omegas\  - \ 
      first\ list\ of\ graded\ symbols\ for\ a\ complete\ set\ of\ CAV\ \ 1 - 
      forms\), "\n", 
    \(25. \ scalars\  - \ list\ of\ 0 - 
      forms\ which\ will\ have\ exterior\ derivatives\ given\ by\ "\<dscalars\
\>"\), "\n", 
    \(\(26. \ scdim\  - \ number\ of\ scalars;\)\  = 
      Length[scalars]\), "\n", 
    \(27. \ sderiv\  - \ \ basic\ rules\ to\ \ give\ exterior\ derivatives\ \
of\ "\<scalars\>"\ \), "\n", 
    \(28. \ sig[i]\  - \ \((\[Gamma]\_i)\)\^2 = \(\[PlusMinus]1\), 
    the\ ith\ eigenvalue, g\_ii, 
    of\ the\ diagonal\ Clifford\ metric\), "\n", 
    \(29. \ signature\  - list\ of\ all\ sig[i]; \ 
    the\ argument\ for\ \ "\<makeclifford[signature]\>"\), "\n", 
    \(30. \ skew\  - \ list\ of\ skew - 
        symmetric\ structure\ \(constants : \ \ sk\_\(i, j, k\) + 
              sk\_\(i, k, j\)\) = 0\t\), "\n", 
    \(\(31. \ sub\  - \ list\ of\ basis\ 1 - 
          forms\ spanning\ a\ subspace;\)\  = \ 
      Complement[forms, cosub]\), "\n", 
    \(32. \ symm\  - \ 
        list\ of\ symmetric\ structure\ \(constants : \ \ sy\_\(i, j, k\) - 
              sy\_\(i, k, j\)\) = 0\t\), "\n", 
    \(33. \ thetas\  - \ 
      second\ list\ of\ graded\ symbols\ for\ a\ complete\ set\ of\ CAV\ \ 1 \
- forms\), "\n", 
    \(34. \ topartials\  - \ 
      replacements\ to\ express\ exterior\ derivatives\ by\ \ partials \
\((subscripts)\)\), "\n", 
    \(35. \ tosub\  - \ 
      replacements\ to\ annul\ "\<cosub\>"\ and\ \ d[
          cosub]\ in\ a\ subspace\), "\n", 
    \(36. \ trivial\  - \ 
      the\ initial\ default\ value\ of\ "\<algebra\>"\ \ having\ \
"\<identity\>"\ in\ most\ positions\), "\n", 
    \(37. \ vec1, vec2, vec3, 
    vec4\  - \ 
      four\ independent\ vectors\ created\ by\ "\<makevectors\>"\), "\n", 
    \(38. \ v1\_i, v2\_i, v3\_i, 
    v4\_i\  - \ 
      the\ components\ of\ the\ above\ vectors\ in\ the\ dual\ basis\ to\ \
"\<forms\>"\), "\n", 
    \(\)}], "Input",
  PageBreakAbove->False,
  PageBreakWithin->False,
  PageBreakBelow->Automatic,
  GroupPageBreakWithin->True,
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["VIIb. Functions", "Subsection",
  PageBreakAbove->True,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  FontFamily->"Courier",
  FontSize->12,
  FontTracking->"Condensed"],

Cell[BoxData[{
    \(The\ \ argument\ "\<avf\>"\ means\ a\ single\ \ algebra - valued - 
      form; \ "\<avf or {avfs}\>"\ \ means\ \), 
    \(either\ a\ single\ avf, 
    or\ a\ list\ of\ them.\ Functions\ with\ CAV\ arguments\ are\ defined\ 
      only\), 
    \(for\ those\ expressions.Empty\ brackets\ mean\ no\ \(arguments.\)\)}], 
  "Input",
  PageBreakAbove->False,
  PageBreakWithin->False,
  PageBreakBelow->False,
  FontFamily->"Courier",
  FontWeight->"Plain"],

Cell[BoxData[{
    \(\ \ 1. \ adjmat[list_of  _elements]\  - \ 
        returns\ \(matrix : adjmat . adjlist\)\  = \ argument_list\), "\n", 
    \(\ \ 2.  adL[element, list_of  _elements]\  - \ 
      returns\ \((element)\) ** {any\ list\ of\ the\ elements}\), "\n", 
    \(\ \ 3. \ adR[list_of  _elements, element]\  - \ 
      returns\ {any\ list\ of\ the\ elements} ** \((element)\)\), "\n", 
    \(\ \ \(4. \ applydrules[avf\ or\ {avfs}]\  - \ 
          implements\ "\<drules\>";\) = \ expand[{avfs} /. drules]\), "\n", 
    \(\ \ 5. \ associators[n]\  - \ 
      returns\ up\ to\ "\<n\>"\ \ associators\ for\ "\<algebra\>"; 
    prints\ number\ found\), "\n", 
    \(\ \ 6. \ coeffs[avf]\  - \ returns\ a\ list\ of\ the\ non - 
      zero\ coefficients\ of\ "\<elements\>"\ in\ "\<avf\>"\), "\n", 
    \(\ \ 7. \ collect[avf\ or\ {avfs}]\  - \ 
      collects\ the\ factors\ of\ "\<elements\>"; 
    displays "\<identity\>"\), "\n", 
    \(\ \ \(8. \ contract[vector, avf\ or\ {avfs}]\  - \ 
            contracts\ "\<vector\>"\ on\ {avfs};\)\[SmallCircle]\ 
        is\ the\ infix\ form\), "\n", 
    \(\ \ 9. \ contractedidentity[]\  - \ 
      differential\ identity\ for\ the\ Einstein\ 3 - 
      form\ \ \(\(G\&^\)\&\ \)\), "\n", 
    \(10. \ curvatureidentity[]\  - \ aka\ Bianchi\ identity; 
    general\ identity\ for\ CAV\ field\ \ \[CapitalOmega]\&^\), "\n", 
    \(11. \ d[avf\ or\ {avfs}]\  - \ 
      returns\ exterior\ derivatives\ of\ arguments\), "\n", 
    \(12. \ da[avf\ or\ {avfs}] - \ 
      shortcut\ \(for : \ \ \ applydrules[d[arguments]]\)\), "\n", 
    \(13. \ \[Delta][avf\ or\ {avfs}]\  - 
        coderivative\ for\ arguments\ expressed\ in\ "\<frame\>" = 
      hs[da[hs[arg]]]\), "\n", 
    \(14. \ D\_sub[avf\ or\ {avfs}]\  - \ 
      coordinate\ derivative\ defined\ by\ "\<makecoords[]\>"\ command\), "\n\
", 
    \(15. \ dot[p - form1, p - form2]\  - \ 
      scalar\ product\ of\ arguments\ expressed\ in\ "\<frame\>"\), "\n", 
    \(16. \ expand[avf\ or\ {avfs}]\  - \ 
      substitutes\ infix\ \ multiplication\ operator\  ** \ for\ \[Wedge]\ \n
          17. \ factor[basisform, avf]\  - \ 
      returns\ the\ righthand\ factor\ of\ "\<basisform\>"\ in\ "\<avf\>"\), \
"\n", 
    \(18. \ generic[]\  - 
      constructs\ a\ general\ "\<algebra\>"\ for\ "\<elements\>" 
        using\ "\<skew\>"\ and\ \ "\<symm\>"\), "\n", 
    \(19. \ grade[integer, CAV]\  - \ 
      returns\ the\ specified\ grade\ of\ a\ CAV\ form\), "\n", 
    \(20. \ grades[CAV]\  - \ 
      returns\ a\ list\ of\ all\ grades\ of\ a\ CAV\ form\), "\n", 
    \(21. \ hs[avf\ or\ {avfs}]\  - \ 
      returns\ the\ Hodge\ dual\ for\ arguments\ expressed\ in\ "\<frame\>"\ \
\), "\n", 
    \(22. \ in[avf]\  - \ 
      converts\ "\<avf\>"\ to\ equivalent\ List\ expression\ for\ AVF\ \
operations\), "\n", 
    \(23. \ involute[CAV]\  - \ 
      changes\ sign\ of\ all\ odd\ grades\ in\ CAV\), "\n", 
    \(24. \ lie[vector, avf\ or\ {avfs}]\  - \ 
      returns\ \ Lie\ derivatives\ of\ "\<avfs\>"\ \ wrt\ "\<vector\>"\), "\n\
", 
    \(25. \ liealgebra[]\  - \ 
      returns\ the\ Lie\ brackets\ of\ the\ dual\ vectors\ to\ non - \ 
      exact\ forms\), "\n", 
    \(26. \ makealgebra[product_matrix] - \ 
      establishes\ the\ multiplication\ table\ for\ "\<elements\>"\), "\n", 
    \(27. \ makeall[]\  - \ 
      in\ CAV\ does \((makethetahat; makeomegahat; maketorsion; 
          makecurvature)\)\), "\n", 
    \(28. \ makeclifford[signature - list]\  - \ 
      makes\ Clifford\ algebra\ with\ specified\ signature\), "\n", 
    \(29. \ makecoords[symbol_list]\  - \ 
      defines\ a\ set\ of\ independent\ scalars\ and\ "\<partials\>"\), "\n", \

    \(30. \ makecurvature[] - \ calculates\ the\ CAV\ \ 2 - 
      form\ \ \[CapitalOmega]\&^\ \ from\ the\ connection\ \ 1 - 
      form\ \ \(\[Omega]\&^\)\), "\n", 
    \(31. \ makedrules[replacement_list] - \ 
      establishes\ "\<drules\>"\ for\ "\<dforms\>"\ \((\(+\ 
              optional\)\ Rules)\)\), "\n", 
    \(32. \ makeeinstein[]\  - \ makes\ a\ CAV\ \ 3 - 
        form\ \ G\&^ = \((\[Theta]\&^\  ** \[CapitalOmega]\&^ + \
\[CapitalOmega]\&^ ** \[Theta]\&^\ )\)/
          2\ \ \((4  dim\ Einstein\ tensor)\)\), "\n", 
    \(33. \ makeelements[symbol_list]\  - \ 
      establishes\ the\ list\ of\ generators\ for\ an\ algebra\), "\n", 
    \(34. \ makeforms[symbol_list]\  - \ 
      establishes\ the\ list\ of\ fundamental\ non - exact\ 1 - 
      forms\), "\n", 
    \(35. \ makeframe[symbol_list]\  - \ 
        defines\ a\ set\ of\ orthonormal\ basis\ forms\  = \ "\<frame\>"\ \), \
"\n", 
    \(36. \ makematrices[]\  - \ 
      constructs\ a\ matrix\ representation\ of\ the\ chosen\ \ Clifford\ \
algebra\ \), "\n", 
    \(37. \ makeomegahat[]\  - \ 
      makes\ the\ generalized\ CAV\ connection\ \ 1 - \ 
      form, \ \(\(\[Omega]\&^\)\&\ \)\), "\n", 
    \(38. \ makescalars[symbol_list]\  - \ 
      establishes\ the\ list\ of\ fundamental\ scalars \((0 - 
            forms)\)\), "\n", 
    \(39. \ makethetahat[]\  - \ 
      makes\ the\ generalized\ CAV\ "\<co-frame\>"\ 1 - 
      form, \ \[Theta]\&^\), "\n", 
    \(40. \ maketorsion[]\  - \ \ calculates\ the\ CAV\ \ 2 - 
      form\ \ \[CapitalTheta]\&^\ \ from\ the\ CAV\ \ 1 - 
      forms\ \ \(\[Theta]\&^\)\ \ and\ \ \(\[Omega]\&^\)\), "\n", 
    \(41. \ makevectors[]\  - \ 
      makes\ a\ set\ of\ four\ lists\ \(named : \((vec1, vec2, vec3, 
            vec4)\)\)\)}], "Input",
  PageBreakAbove->False,
  PageBreakWithin->False,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"],

Cell[BoxData[{
    \(42. \ matmult[m1, m2]\  - \ \ multiplication\ of\ AVF\ \ matrices; 
    infix\ operator, \ m1\[CircleTimes]\ m2\), "\n", 
    \(43. \ mtx[avf_\ array]\  - \ 
      outputs\ the\ argument\ in\ MatrixForm; "\<algebra\>"\ is\ default\ \
argument\), "\n", 
    \(44. \ mult[avf1, avf2]\  - \ returns\ the\ product, \ avf1 ** avf2, \ 
    where\  ** \ is\ the\ infix\ form\), "\n", 
    \(45. \ out[List_form  _of  _avf]\  - \ left\ inverse\ of\ in[avf]; 
    i . e . , avf == out[in[avf]]\), "\n", 
    \(46. \ prune[list, exp]\  - \ 
      keeps\ only\ those\ members\ of\ "\<list\>" 
        that\ \ appear\ in\ "\<exp\>"\), "\n", 
    \(\(47. \ pullback[avf\ or\ {avfs}]\  - \ 
          pulls\ back\ {avfs}\ into\ subspace "\<sub\>";\) = {avfs} /. 
        tosub\), "\n", 
    \(48. \ reset[] - \ set\ "\<timer\>"\ to\ zero\), "\n", 
    \(49. \ reverse[CAV]\  - \ returns\ the\ "\<reversion\>"\ of\ CAV; \ 
    equiv . to\ reversing\ all\ \[Gamma]\_i\ products\), "\n", 
    \(\(50. \ setzero[list_of  _expressions]\  - \ 
          turns\ the\ \ arg\ list\ into\ a\ list\ of\ equations;\) == 
      0\), "\n", 
    \(51. \ subspace[list_of  _basis  _  1 - forms]\  - \ 
      make\ replacement\ list\ "\<tosub\>"\ for\ "\<pullback\>"\), "\n", 
    \(52. \ timer[]\  - \ 
      returns\ elapsed\ time\ from\ most\ recent\ "\<reset\>"\), "\n", 
    \(53. \ torsionidentity[]\  - \ \ general\ identity\ for\ CAV\ field, \
\[CapitalTheta]\&^\ ; \(\(aka\)\(\ \)\(Cartan\)\(\ \)\(identity\)\(\ \ \
\)\)\), "\n", 
    \(54.  zerocurvature[]\  - \ 
      constructs\ a\ list\ of\ "\<drules\>"\ giving\ vanishing\ CAV\ \
curvature\ \ \[CapitalOmega]\&^\), "\n", 
    \(55.  zerotorsion[]\  - \ 
      constructs\ a\ list\ of\ "\<drules\>"\ giving\ vanishing\ CAV\ torsion\
\ \ \(\(\[CapitalTheta]\&^\)\&\ \)\)}], "Input",
  PageBreakAbove->False,
  PageBreakWithin->False,
  PageBreakBelow->Automatic,
  FontWeight->"Plain"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
WindowSize->{702, 512},
WindowMargins->{{4, Automatic}, {Automatic, -2}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          OptionValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{36, 36}, {36, 72}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True},
ShowCellLabel->False,
StyleDefinitions -> "HelpBrowser.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?mooh<<H`Ui0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000Gd000400@eQYk0000000000060801T1T00000000000
00000000004000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 261, 8, 45, "Input"],
Cell[2018, 61, 72, 1, 26, "Input"],

Cell[CellGroupData[{
Cell[2115, 66, 133, 4, 48, "Section",
  PageBreakBelow->Automatic],
Cell[2251, 72, 289, 6, 40, "Input",
  PageBreakBelow->Automatic],
Cell[2543, 80, 1592, 29, 265, "Input",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[4172, 114, 192, 6, 48, "Section",
  PageBreakAbove->True,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[4367, 122, 426, 10, 70, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[4796, 134, 133, 4, 25, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[4932, 140, 392, 11, 46, "Input",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[5327, 153, 208, 5, 25, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[5560, 162, 202, 6, 33, "Subsection",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[5765, 170, 412, 8, 55, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[6180, 180, 354, 8, 40, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[6537, 190, 495, 11, 106, "Input",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[7035, 203, 346, 8, 40, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[7384, 213, 1375, 37, 154, "Input",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[8762, 252, 1949, 54, 100, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[10714, 308, 1807, 51, 70, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[12524, 361, 980, 25, 106, "Input",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[13507, 388, 259, 7, 25, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[13769, 397, 898, 21, 58, "Input",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[14670, 420, 852, 16, 175, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[15525, 438, 266, 7, 42, "Input",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[15794, 447, 291, 6, 40, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[16122, 458, 222, 7, 33, "Subsection",
  PageBreakAbove->True,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[16347, 467, 745, 16, 85, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[17095, 485, 747, 15, 85, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[17845, 502, 1097, 22, 85, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[18945, 526, 928, 18, 100, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[19876, 546, 538, 12, 55, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[20451, 563, 188, 6, 33, "Subsection",
  PageBreakAbove->True,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[20642, 571, 5536, 159, 85, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[26181, 732, 942, 16, 90, "Input",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[27126, 750, 639, 13, 70, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[27768, 765, 168, 4, 25, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[27939, 771, 398, 8, 42, "Input",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[28340, 781, 582, 11, 70, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[28925, 794, 975, 21, 115, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[29903, 817, 520, 11, 70, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[30426, 830, 994, 20, 102, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[31469, 856, 162, 5, 48, "Section",
  PageBreakAbove->True,
  PageBreakBelow->Automatic],
Cell[31634, 863, 199, 4, 25, "Input",
  PageBreakBelow->Automatic],
Cell[31836, 869, 1347, 28, 93, "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic],
Cell[33186, 899, 1608, 43, 187, "Input",
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[34819, 946, 132, 4, 33, "Subsection",
  PageBreakBelow->Automatic],
Cell[34954, 952, 588, 13, 107, "Input",
  PageBreakBelow->Automatic],
Cell[35545, 967, 1241, 29, 106, "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic],
Cell[36789, 998, 873, 22, 187, "Input",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[37699, 1025, 133, 4, 33, "Subsection",
  PageBreakBelow->Automatic],
Cell[37835, 1031, 537, 16, 123, "Input",
  PageBreakBelow->Automatic]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[38421, 1053, 166, 5, 48, "Section",
  PageBreakAbove->True,
  PageBreakBelow->Automatic],
Cell[38590, 1060, 362, 8, 40, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[38977, 1072, 149, 7, 48, "Subsection",
  PageBreakBelow->Automatic],
Cell[39129, 1081, 764, 16, 115, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[39896, 1099, 336, 7, 42, "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic],
Cell[40235, 1108, 1159, 23, 145, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[41397, 1133, 559, 12, 70, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[41959, 1147, 469, 10, 70, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[42465, 1162, 159, 5, 33, "Subsection",
  PageBreakAbove->True,
  PageBreakBelow->Automatic],
Cell[42627, 1169, 1114, 22, 85, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[43744, 1193, 435, 8, 42, "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic],
Cell[44182, 1203, 163, 5, 25, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[44348, 1210, 2032, 59, 57, "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic],
Cell[46383, 1271, 579, 13, 85, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[46999, 1289, 144, 4, 33, "Subsection",
  PageBreakBelow->Automatic],
Cell[47146, 1295, 953, 18, 115, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[48102, 1315, 716, 14, 85, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[48821, 1331, 722, 16, 85, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[49546, 1349, 1017, 21, 74, "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic],
Cell[50566, 1372, 917, 17, 85, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[51486, 1391, 541, 14, 55, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[52030, 1407, 383, 8, 58, "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic],
Cell[52416, 1417, 595, 12, 85, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[53014, 1431, 524, 14, 91, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[53541, 1447, 483, 9, 58, "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic],
Cell[54027, 1458, 182, 5, 25, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[54212, 1465, 335, 7, 42, "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[54596, 1478, 169, 5, 48, "Section",
  PageBreakAbove->True,
  PageBreakBelow->Automatic],
Cell[54768, 1485, 846, 18, 115, "Input",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[55617, 1505, 3884, 99, 90, "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic],
Cell[59504, 1606, 170, 4, 40, "Input",
  PageBreakBelow->Automatic],
Cell[59677, 1612, 372, 8, 42, "Input",
  Evaluatable->False,
  PageBreakBelow->Automatic],
Cell[60052, 1622, 683, 12, 100, "Input",
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[60772, 1639, 191, 6, 48, "Section",
  PageBreakAbove->True,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[60966, 1647, 649, 13, 71, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[61618, 1662, 483, 11, 43, "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[62104, 1675, 380, 9, 40, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[62487, 1686, 586, 12, 58, "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[63076, 1700, 177, 5, 25, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[63256, 1707, 563, 11, 58, "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[63822, 1720, 230, 6, 25, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[64055, 1728, 577, 11, 58, "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[64635, 1741, 241, 6, 25, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[64901, 1751, 204, 6, 33, "Subsection",
  PageBreakAbove->True,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[65108, 1759, 412, 10, 40, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[65523, 1771, 1140, 24, 115, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[66666, 1797, 328, 8, 40, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[66997, 1807, 430, 9, 42, "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[67430, 1818, 877, 18, 85, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[68344, 1841, 214, 6, 33, "Subsection",
  PageBreakAbove->True,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[68561, 1849, 438, 10, 40, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[69002, 1861, 781, 14, 75, "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[69786, 1877, 398, 9, 42, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[70187, 1888, 1727, 28, 267, "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[71917, 1918, 531, 12, 55, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[72451, 1932, 672, 14, 75, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[73126, 1948, 1085, 19, 122, "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[74214, 1969, 408, 10, 40, "Input",
  PageBreakAbove->True,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[74625, 1981, 774, 16, 163, "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[75402, 1999, 520, 12, 97, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[75925, 2013, 711, 15, 124, "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[76639, 2030, 609, 14, 74, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[77251, 2046, 852, 16, 93, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[78106, 2064, 526, 12, 130, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[78635, 2078, 316, 8, 40, "Input",
  PageBreakAbove->True,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[78954, 2088, 697, 14, 124, "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[79654, 2104, 505, 12, 55, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[80162, 2118, 907, 19, 106, "Input",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[81072, 2139, 453, 11, 57, "Input",
  Evaluatable->False,
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[81574, 2156, 209, 6, 48, "Section",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[81786, 2164, 639, 14, 70, "Input",
  PageBreakAbove->False,
  PageBreakWithin->False,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[82450, 2182, 230, 7, 33, "Subsection",
  PageBreakAbove->Automatic,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[82683, 2191, 4911, 107, 601, "Input",
  PageBreakAbove->False,
  PageBreakWithin->False,
  PageBreakBelow->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[87631, 2303, 190, 6, 33, "Subsection",
  PageBreakAbove->True,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],
Cell[87824, 2311, 472, 12, 55, "Input",
  PageBreakAbove->False,
  PageBreakWithin->False,
  PageBreakBelow->False],
Cell[88299, 2325, 5555, 112, 648, "Input",
  PageBreakAbove->False,
  PageBreakWithin->False,
  PageBreakBelow->Automatic],
Cell[93857, 2439, 1938, 38, 231, "Input",
  PageBreakAbove->False,
  PageBreakWithin->False,
  PageBreakBelow->Automatic]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

