(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     25205,        900]*)
(*NotebookOutlinePosition[     26119,        929]*)
(*  CellTagsIndexPosition[     26075,        925]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    RowBox[{"\n", 
      StyleBox[\(IMPLEMENTING\ CLIFFORD\ ALGEBRAS\),
        FontFamily->"Helvetica",
        FontSize->14,
        FontVariations->{"Underline"->True}]}]], "Input"],

Cell["\<\
(*This program can be executed all at once by Evaluate \
Initialization and then scrolled through.  Because it frequently uses \"%\" \
to reference prior output, it will not execute properly with Evaluate \
Notebook.  Printing a copy of the notebook can serve as a reference manual \
for the CAV operations and syntax. It is always safer to start with a fresh \
Kernel. Total running time: ~1 min.*)
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(<< AVF.m;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\n (*MAKING\ A\ CLIFFORD\ ALGEBRA*) \)\)], "Input"],

Cell["\<\
(*A Clifford algebra representation of quaternions will be used as \
the first example. The argument of \"makeclifford[arg]\" is the desired \
signature list; i.e., for quaternions, {-1 , -1}.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makeclifford[{\(-1\), \(-1\)}]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The dimension is given by \"cadim\", and the \"elements\" list \
has length \"eldim\" =  2^cadim.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(cadim\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(elements\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(eldim\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*The first element, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\_0\)]],
  ", is the identity; ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\_1\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\_2\)]],
  "are the orthonormal generators, both with negative signature; and the \
complete product element here is, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\_3\)]],
  "= ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\[Gamma]\_1\),
            "TraditionalForm"], \(\[Gamma]\_2\)}], TraditionalForm]]],
  ", which also has a negative square. The command \"mtx[]\" outputs the \
algebra table in MatrixForm.*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(mtx[]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*As described in ",
  ButtonBox["AVF_Introduction.nb",
    ButtonData:>{"   AVF_Introduction.nb", None},
    ButtonStyle->"Hyperlink"],
  ", all the following graded symbol lists and CAV quantites are \
constructed:*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(gammas\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(thetas\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(omegas\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(forms\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\[Theta]\&^\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\[Omega]\&^\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*The generalized torsion and curvature 2-forms are defined by the CAV \
expressions;\n\n          ",
  Cell[BoxData[
      \(\(\(\ \ \)\(\[CapitalTheta]\&^\  = \ 
        d[\[Theta]\&^] + \(1\/2\) \((\[Omega]\&^ ** \[Theta]\&^ + \[Theta]\&^ \
** \[Omega]\&^)\)\)\)\)], "Input"],
  "\n          \n           ",
  Cell[BoxData[
      \(\(\(\ \)\(\[CapitalOmega]\&^\  = \ 
        d[\[Omega]\&^] + \(\(1\/2\) \((\[Omega]\&^ ** \[Omega]\&^)\)\(\ \
\)\)\)\)\)], "Input"],
  "\n\nand can be evaluated for any assigned { ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\&^\)]],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\&^\)]],
  " } with the functions;*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(maketorsion[]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makecurvature[]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*The identity element, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\_0\)]],
  ", appears explicitly because the functions use the \"collect\" command to  \
group the expressions into coefficients of \"elements\". These expressions \
are assigned to the variable names, ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalTheta]\&^\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalOmega]\&^\)]],
  " . They satisfy the general differential identities given in \
AVF_Introduction.nb .*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(curvatureidentity[]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(torsionidentity[]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*A general 0-form quaternion with constant components can be \
constructed by,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(q\&^ = \[Omega]\&^ /. \[Omega] -> q\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and the components become scalar fields when established as \
\"scalars\",*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makescalars[coeffs[q\&^]]\)], "Input",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(collect[q\&^ ** d[q\&^]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[%]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\n\n (*CLIFFORD\ ALGEBRA\ FOR\ A\ SPACETIME\ METRIC*) \)\)], "Input"],

Cell["(*Using a Lorentzian 4-space signature:*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makeclifford[{\(-1\), 1, 1, 1}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(elements\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(forms\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(mtx[]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*The general values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\&^\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\&^\)]],
  " , including all grades, are assigned by the \"makeclifford\" command. *)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\[Theta]\&^\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\[Omega]\&^\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*The CAV 2-forms of generalized torsion  ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalTheta]\&^\)]],
  "  and curvature  ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalOmega]\&^\)]],
  "  can be constructed using those values:*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(maketorsion[]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makecurvature[]\)], "Input",
  InitializationCell->True],

Cell["(*and again the differential identities can be verified.*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(torsionidentity[]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(curvatureidentity[]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The following two commands solve for all \"dforms\" by annulling \
first torsion and then curvature,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(zt = zerotorsion[]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(zc = zerocurvature[]\)], "Input",
  InitializationCell->True],

Cell["(*and this establishes the solution as \"drules\",*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(makedrules[Join[zt, zc]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(applydrules[{\[CapitalTheta]\&^, \[CapitalOmega]\&^}]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*These \"drules\" are shown to represent valid Maurer-Cartan \
relations of a closed Lie algebra by the next result. The inner application, \
da[forms], just returns \"dforms\" and then replaces them by the rhs of the \
\"drules\", but the second outer da[] differentiates each of those \
expressions, substitutes back all the \"drules\" into them, and expands the \
resulting 3-forms. For 32 such lengthy expressions, this takes some time.*)\
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(da[da[forms]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\n\n (*A\ RIEMANNIAN\ GEOMETRY\ PROBLEM*) \)\)], "Input"],

Cell["\<\
(*For the following problem of spherically symmetric spacetimes, we \
use a truncated Clifford algebra. The \"algebra\" can be truncated since \
Riemannian geometry only requires doing products up to grade[2];*)\
\>", \
"Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makeclifford[{\(-1\), 1, 1, 1}, 2]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(mtx[]\)], "Input",
  InitializationCell->True],

Cell["\<\

(*We want the CAV co-frame to be grade[1] and the CAV connection to be \
grade[2],*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[{
    \(\[Theta]\&^ = grade[1, \[Theta]\&^]\), "\n", 
    \(\[Omega]\&^ = grade[2, \[Omega]\&^]\)}], "Input",
  InitializationCell->True],

Cell["(*Introduce a set of scalar variables for coordinates,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makescalars[{t, r, \[Theta], \[Phi]}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(dscalars\)], "Input",
  InitializationCell->True],

Cell["\<\
(* The input required is to give coordinate expressions for the \
orthonormal frame forms. We specify r as the curvature coordinate in the line \
element,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(-T[r]\^2\) dt\^2 + \ \(R[r]\^2\) dr\^2 + \ \(r\^2\) 
          d\[Theta]\^2 + \ 
        r\^2\ \(Sin[\[Theta]]\^2\) d\[Phi]\^2;\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(tocoords = 
      Thread[coeffs[\[Theta]\&^] -> {T[r] dt, R[r] dr, r\ d\[Theta], 
            r\ Sin[\[Theta]]\ d\[Phi]}]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*so in the coordinate basis, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\&^\)]],
  " becomes,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\[Theta]\&^ = \[Theta]\&^ /. tocoords\)], "Input",
  InitializationCell->True],

Cell["\<\
(*At this point, many Clifford algebra approaches define new \
variable \"elements\" by,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Thread[
      Coefficient[%, 
          dscalars] -> {\[Gamma]\_t, \[Gamma]\_r, \[Gamma]\_\[Theta], \
\[Gamma]\_\[Phi]}]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*giving an equivalent expression for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\&^\)]],
  " ,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\[Theta]\&^ /. %\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The AVF program, however, is based throughout on constant algebra \
elements with any spatial dependence residing in their p-form coefficients.*)\
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(\n\)\( (*DERIVING\ THE\ FIELD\ EQUATIONS*) \)\)\)], "Input"],

Cell["\<\
(*For demonstration, the steps will be presented in detail. \
Generally, most of it can be automated, as shown in Riemann.nb, using the \
auxiliary program orthoframes.nb.*)\
\>", "Input",
  FontFamily->"Times"],

Cell["\<\
(*To find the connection we can expand its components on the frame \
1-forms, using a non-standard matrix of 24 rotation coefficients. Either the \
coordinate, or the orthonormal, basis 1-forms can be used. Here we use the \
coordinate 1-forms, which is a bit more straightforward since it doesn't \
require defining \"drules\".*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(MK = Table[K\_\(i, j\), {i, 4}, {j, 6}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(onframe = Thread[coeffs[\[Omega]\&^] -> dscalars . MK]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\[Omega]\&^ = \[Omega]\&^ /. onframe\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*With this  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\&^\)]],
  "  the torsion becomes,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(tor = maketorsion[]\)], "Input",
  InitializationCell->True],

Cell["(*The independent 2-forms are given by,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(twobasis = {dr\[Wedge]d\[Theta], dr\[Wedge]d\[Phi], dr\[Wedge]dt, 
        dt\[Wedge]d\[Theta], dt\[Wedge]d\[Phi], 
        d\[Theta]\[Wedge]d\[Phi]}\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and the List multiplication statement, Outer[], constructs the 24 \
independent   (gammas)*(twobasis) components,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(comps = 
      Flatten[Outer[Times, prune[elements, tor], twobasis]]\)], "Input",
  InitializationCell->True],

Cell["(*all coefficients of which must vanish for zero torsion.*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(terms = Coefficient[tor, comps]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The \"setzero\" command simply equates its list of arguments to \
zero giving equations for Solve,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(eqns = setzero[terms]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(soln = Flatten[Solve[%, Flatten[MK]]]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*and the final result for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\&^\)]],
  " is,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\[Omega]\&^ = \[Omega]\&^ /. soln\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*To verify the solution, this ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\&^\)]],
  " can be used to calculate the torsion again,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(maketorsion[]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*Constructing the CAV curvature 2-form from this  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\&^\)]],
  " ,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makecurvature[]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*which shows only ",
  Cell[BoxData[
      \(TraditionalForm\`R\_\(i, j, i, j\)\)]],
  " components.*)"
}], "Input",
  FontFamily->"Times"],

Cell[TextData[{
  "(*The CAV grade[3] 3-form, ",
  Cell[BoxData[
      \(TraditionalForm\`G\&^\)]],
  " , is the differential form expression of the Einstein tensor,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(G\&^ = collect[Simplify[makeeinstein[]]]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*Mathematica could be asked to DSolve the field equations, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(G\)\(\ \)\)\&^\)]],
  "= 0 ,but just for demonstration,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Schwarzschild = {R -> Function[r, 1/\@\(1 - 2\ m/r\)], 
        T -> Function[r, \@\(1 - 2\ m/r\)]}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Simplify[G\&^ /. Schwarzschild]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*One advantage of using orthonormal frame forms is that the built-in \
Hodge star operator becomes available. (See ",
  ButtonBox["HodgeStar_Demo.nb",
    ButtonData:>{"  HodgeStar_Demo.nb", None},
    ButtonStyle->"Hyperlink"],
  "). Using the \"thetas\" list, and Mathematica's Thread to get the Clifford \
signature in, saves some typing,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Thread[signature\ \ Take[thetas, {2, 5}]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makeframe[%]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(signature\)], "Input",
  InitializationCell->True],

Cell["(*and \"frame\" is now at the front of \"forms\";*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(forms\)], "Input",
  InitializationCell->True],

Cell["(*The Hodge star function is written, hs[arg]; e.g.,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(hs[1]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(hs[%]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Using it on more general expressions requires setting up the \
inverse transformation and appropriate\"drules\"; i.e.,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(toframe = 
      Flatten[Solve[\((tocoords /. Rule -> Equal)\), dscalars]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(dframe = expand[d[frame /. tocoords] /. toframe]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(dframerules = Thread[d[frame] -> dframe]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makedrules[Join[dframerules, toframe]]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The HodgeStar program includes a symmetric product for p-forms of \
the same degree, denoted dot[p1,p2], and with the above \"drules\", it can be \
used to give the covariant metric tensor in the coordinate basis, which \
simply confirms the set-up statements,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(mtx[
      Inverse[Table[
          dot[dscalars[\([i]\)], dscalars[\([j]\)]], {i, 4}, {j, 
            4}]]]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and the AVF Einstein 3-form can be converted to a dual 1-form, \
making its diagonal structure clearer,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(collect[hs[G\&^]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Simplify[% /. Schwarzschild]\)], "Input",
  InitializationCell->True],

Cell["\<\
*(The Hodge operators will return the wave equation for a function \
of coordinates in this metric. Defining the \"scalars\" as \"coords\" simply \
gives a better formatting for partial derivatives;*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makecoords[scalars]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(f = \[CapitalPsi][depend]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[f]\)], "Input",
  InitializationCell->True],

Cell["(*The scalar wave equation is,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\[Delta][d[f]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(% /. Schwarzschild\)], "Input",
  InitializationCell->True],

Cell["(*and for flat spacetime,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(% /. m -> 0\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\n (*MATRIX\ REPRESENTATIONS\ FOR\ CLIFFORD\ ALGEBRAS*) \)\)], "Input"],

Cell["\<\
(*The CAV program includes a \"makematrices[]\" command which \
constructs a set of matrices for the algebra \"elements\" (gammas) of the \
active Clifford algebra. They are denoted by upper case, \[CapitalGamma], \
with the same indices as the lower case \"elements\", so that CAV expressions \
can be converted to matrix form by replacement of the symbol kernel. The \
matrices have dimension 2^p with p = cadim/2 for cadim even, and p = \
(cadim-1)/2 for cadim odd. For example, in the present case,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[{
    \(makematrices[]\), "\n", 
    \(\[CapitalGamma]\_0\), "\n", 
    \(\[CapitalGamma]\_1\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\((\(-\[CapitalGamma]\_1\))\) . \[CapitalGamma]\_1 == \
\((\[CapitalGamma]\_2)\) . \[CapitalGamma]\_2 == \((\[CapitalGamma]\_3)\) . \
\[CapitalGamma]\_3 == \((\[CapitalGamma]\_4)\) . \[CapitalGamma]\_4 == \
\[CapitalGamma]\_0\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\[CapitalGamma]\_24\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\[Gamma]\_24 /. \[Gamma] -> \[CapitalGamma]\)], "Input",
  InitializationCell->True],

Cell["(*and for a CAV expression,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\[Omega]\&^\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(mat\[Omega] = % /. \[Gamma] -> \[CapitalGamma]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Any AVF matrices can be multiplied by the CircleTimes infix \
operator,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(mat\[Omega]\[CircleTimes]mat\[Omega]\)], "Input",
  InitializationCell->True],

Cell["(*which must give the same result as,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\[Omega]\&^ ** \[Omega]\&^ /. \[Gamma] -> \[CapitalGamma]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*The \"makematrices[S]\" command will accept as an argument any \
invertible 2^p matrix, S, and will perform a similarity transformation, ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_i\)]],
  "\[Rule] S ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\[CapitalGamma]\_i\),
            "TraditionalForm"], \(S\^\(-1\)\)}], TraditionalForm]]],
  ", on the matrices returned by the function. For example,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Q = {{0, a, 0, 0}, {\(-b\), 0, 0, 0}, {0, 0, 0, \(-c\)}, {0, 0, d, 
          0}}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Inverse[Q]\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(makematrices[Q]\), "\n", 
    \(\[CapitalGamma]\_1\), "\n", 
    \(\[CapitalGamma]\_4\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\((\[CapitalGamma]\_1)\) . \[CapitalGamma]\_1\), "\n", 
    \(\((\[CapitalGamma]\_1)\) . \[CapitalGamma]\_4 + \
\((\[CapitalGamma]\_4)\) . \[CapitalGamma]\_1\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\n (*THE\ CliffordAlgebras\ FOLDER*) \)\)], "Input"],

Cell["\<\
(*There is just one CAV variable available before using \
\"makeclifford[]\" . Named \"clifflist\", it contains a list of the files in \
the \"CliffordAlgebras\" folder.*) \
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(clifflist\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Filenames begin with \"Cl\" followed by parentheses containing \
either 1 or 2 parameters, separated by commas. The first is just a string of \
plus and minus signs, representing the signature. The second parameter is \
optional. It specifies the highest grade of \"elements\"(gammas) for which \
the table of products (\"algebra\") has been calculated. When omitted, the \
\"algebra\" table is constructed for all grades, assuming enough memory is \
available to accomplish it. In the \"clifflist\" given above, all the higher \
dimensional algebras (cadim>6) have been truncated to grade(2) for economy.

Note that the signature argument for the \"makeclifford[]\" function is not \
in the same format as the filenames. It is typed by giving the List of  \
\[PlusMinus] 1 eigenvalues, as demonstrated in the above examples, followed \
by the grade restriction if desired. After converting that List to the \
appropriate filename, \"makeclifford[]\" looks for it in \"clifflist\" and if \
found, reads the file. For example, the quaternion filename, Cl(- -), was \
found and that file was input, as were all the other examples used above.

If the filename of the required algebra is not included in the list, the \
algebra will be constructed, which will take some time for cadim > 5. Any \
difference in the signature from those in \"clifflist\" will launch a new \
construction; i.e., unless all positions of  \[PlusMinus] 1 match. The \
resulting algebra and associated quantities are output to a file in the \
CliffordAlgebras folder, and it's filename is added to \"clifflist\".*)\
\>", \
"Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(timer[]\)], "Input",
  InitializationCell->True]
},
FrontEndVersion->"4.2 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
AutoGeneratedPackage->None,
WindowSize->{666, 498},
WindowMargins->{{8, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@D>?/0000000000060801T1T00000000000
00000000000000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 198, 5, 43, "Input"],
Cell[1955, 58, 448, 9, 92, "Input"],
Cell[2406, 69, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[2483, 73, 73, 1, 43, "Input"],
Cell[2559, 76, 242, 5, 44, "Input"],
Cell[2804, 83, 91, 2, 27, "Input",
  InitializationCell->True],
Cell[2898, 87, 149, 4, 28, "Input"],
Cell[3050, 93, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[3119, 97, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[3191, 101, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[3260, 105, 726, 23, 60, "Input"],
Cell[3989, 130, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[4058, 134, 274, 8, 44, "Input"],
Cell[4335, 144, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[4405, 148, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[4475, 152, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[4545, 156, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[4614, 160, 72, 2, 29, "Input",
  InitializationCell->True],
Cell[4689, 164, 72, 2, 27, "Input",
  InitializationCell->True],
Cell[4764, 168, 726, 20, 133, "Input"],
Cell[5493, 190, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[5570, 194, 76, 2, 27, "Input",
  InitializationCell->True],
Cell[5649, 198, 567, 15, 61, "Input"],
Cell[6219, 215, 80, 2, 27, "Input",
  InitializationCell->True],
Cell[6302, 219, 78, 2, 27, "Input",
  InitializationCell->True],
Cell[6383, 223, 129, 4, 28, "Input"],
Cell[6515, 229, 96, 2, 28, "Input",
  InitializationCell->True],
Cell[6614, 233, 126, 4, 28, "Input"],
Cell[6743, 239, 109, 3, 28, "Input",
  InitializationCell->True],
Cell[6855, 244, 85, 2, 28, "Input",
  InitializationCell->True],
Cell[6943, 248, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[7011, 252, 91, 1, 59, "Input"],
Cell[7105, 255, 81, 1, 28, "Input"],
Cell[7189, 258, 92, 2, 27, "Input",
  InitializationCell->True],
Cell[7284, 262, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[7356, 266, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[7425, 270, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[7494, 274, 286, 9, 29, "Input"],
Cell[7783, 285, 72, 2, 29, "Input",
  InitializationCell->True],
Cell[7858, 289, 72, 2, 27, "Input",
  InitializationCell->True],
Cell[7933, 293, 299, 9, 29, "Input"],
Cell[8235, 304, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[8312, 308, 76, 2, 27, "Input",
  InitializationCell->True],
Cell[8391, 312, 98, 1, 28, "Input"],
Cell[8492, 315, 78, 2, 27, "Input",
  InitializationCell->True],
Cell[8573, 319, 80, 2, 27, "Input",
  InitializationCell->True],
Cell[8656, 323, 152, 4, 28, "Input"],
Cell[8811, 329, 79, 2, 27, "Input",
  InitializationCell->True],
Cell[8893, 333, 81, 2, 27, "Input",
  InitializationCell->True],
Cell[8977, 337, 92, 1, 28, "Input"],
Cell[9072, 340, 90, 2, 27, "Input",
  InitializationCell->True],
Cell[9165, 344, 114, 2, 31, "Input",
  InitializationCell->True],
Cell[9282, 348, 493, 9, 76, "Input"],
Cell[9778, 359, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[9855, 363, 79, 1, 59, "Input"],
Cell[9937, 366, 261, 6, 44, "Input"],
Cell[10201, 374, 95, 2, 27, "Input",
  InitializationCell->True],
Cell[10299, 378, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[10368, 382, 133, 5, 44, "Input"],
Cell[10504, 389, 150, 3, 48, "Input",
  InitializationCell->True],
Cell[10657, 394, 96, 1, 28, "Input"],
Cell[10756, 397, 98, 2, 27, "Input",
  InitializationCell->True],
Cell[10857, 401, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[10929, 405, 204, 5, 44, "Input"],
Cell[11136, 412, 194, 4, 29, "Input",
  InitializationCell->True],
Cell[11333, 418, 182, 4, 31, "Input",
  InitializationCell->True],
Cell[11518, 424, 161, 6, 29, "Input"],
Cell[11682, 432, 98, 2, 29, "Input",
  InitializationCell->True],
Cell[11783, 436, 138, 4, 28, "Input"],
Cell[11924, 442, 181, 5, 27, "Input",
  InitializationCell->True],
Cell[12108, 449, 162, 6, 29, "Input"],
Cell[12273, 457, 77, 2, 29, "Input",
  InitializationCell->True],
Cell[12353, 461, 197, 5, 44, "Input"],
Cell[12553, 468, 84, 1, 43, "Input"],
Cell[12640, 471, 221, 5, 44, "Input"],
Cell[12864, 478, 378, 7, 60, "Input"],
Cell[13245, 487, 100, 2, 28, "Input",
  InitializationCell->True],
Cell[13348, 491, 115, 2, 27, "Input",
  InitializationCell->True],
Cell[13466, 495, 97, 2, 27, "Input",
  InitializationCell->True],
Cell[13566, 499, 157, 6, 28, "Input"],
Cell[13726, 507, 80, 2, 27, "Input",
  InitializationCell->True],
Cell[13809, 511, 81, 1, 28, "Input"],
Cell[13893, 514, 210, 4, 27, "Input",
  InitializationCell->True],
Cell[14106, 520, 165, 4, 44, "Input"],
Cell[14274, 526, 129, 3, 27, "Input",
  InitializationCell->True],
Cell[14406, 531, 99, 1, 28, "Input"],
Cell[14508, 534, 92, 2, 27, "Input",
  InitializationCell->True],
Cell[14603, 538, 150, 4, 28, "Input"],
Cell[14756, 544, 82, 2, 27, "Input",
  InitializationCell->True],
Cell[14841, 548, 98, 2, 27, "Input",
  InitializationCell->True],
Cell[14942, 552, 153, 6, 28, "Input"],
Cell[15098, 560, 94, 2, 27, "Input",
  InitializationCell->True],
Cell[15195, 564, 197, 6, 28, "Input"],
Cell[15395, 572, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[15472, 576, 175, 6, 28, "Input"],
Cell[15650, 584, 76, 2, 27, "Input",
  InitializationCell->True],
Cell[15729, 588, 159, 6, 28, "Input"],
Cell[15891, 596, 204, 6, 29, "Input"],
Cell[16098, 604, 101, 2, 30, "Input",
  InitializationCell->True],
Cell[16202, 608, 221, 6, 29, "Input"],
Cell[16426, 616, 160, 3, 33, "Input",
  InitializationCell->True],
Cell[16589, 621, 92, 2, 32, "Input",
  InitializationCell->True],
Cell[16684, 625, 400, 9, 60, "Input"],
Cell[17087, 636, 102, 2, 27, "Input",
  InitializationCell->True],
Cell[17192, 640, 73, 2, 27, "Input",
  InitializationCell->True],
Cell[17268, 644, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[17341, 648, 91, 1, 28, "Input"],
Cell[17435, 651, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[17504, 655, 94, 1, 28, "Input"],
Cell[17601, 658, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[17670, 662, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[17739, 666, 170, 4, 44, "Input"],
Cell[17912, 672, 135, 3, 27, "Input",
  InitializationCell->True],
Cell[18050, 677, 109, 2, 27, "Input",
  InitializationCell->True],
Cell[18162, 681, 101, 2, 27, "Input",
  InitializationCell->True],
Cell[18266, 685, 99, 2, 27, "Input",
  InitializationCell->True],
Cell[18368, 689, 312, 6, 60, "Input"],
Cell[18683, 697, 170, 5, 27, "Input",
  InitializationCell->True],
Cell[18856, 704, 155, 4, 28, "Input"],
Cell[19014, 710, 78, 2, 32, "Input",
  InitializationCell->True],
Cell[19095, 714, 89, 2, 27, "Input",
  InitializationCell->True],
Cell[19187, 718, 248, 5, 44, "Input"],
Cell[19438, 725, 80, 2, 27, "Input",
  InitializationCell->True],
Cell[19521, 729, 86, 2, 27, "Input",
  InitializationCell->True],
Cell[19610, 733, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[19678, 737, 72, 1, 28, "Input"],
Cell[19753, 740, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[19831, 744, 79, 2, 27, "Input",
  InitializationCell->True],
Cell[19913, 748, 67, 1, 28, "Input"],
Cell[19983, 751, 72, 2, 27, "Input",
  InitializationCell->True],
Cell[20058, 755, 93, 1, 43, "Input"],
Cell[20154, 758, 552, 9, 92, "Input"],
Cell[20709, 769, 147, 4, 59, "Input",
  InitializationCell->True],
Cell[20859, 775, 286, 5, 27, "Input",
  InitializationCell->True],
Cell[21148, 782, 80, 2, 27, "Input",
  InitializationCell->True],
Cell[21231, 786, 104, 2, 27, "Input",
  InitializationCell->True],
Cell[21338, 790, 69, 1, 28, "Input"],
Cell[21410, 793, 72, 2, 27, "Input",
  InitializationCell->True],
Cell[21485, 797, 107, 2, 27, "Input",
  InitializationCell->True],
Cell[21595, 801, 123, 4, 28, "Input"],
Cell[21721, 807, 97, 2, 27, "Input",
  InitializationCell->True],
Cell[21821, 811, 79, 1, 28, "Input"],
Cell[21903, 814, 118, 2, 27, "Input",
  InitializationCell->True],
Cell[22024, 818, 499, 13, 44, "Input"],
Cell[22526, 833, 142, 3, 27, "Input",
  InitializationCell->True],
Cell[22671, 838, 71, 2, 27, "Input",
  InitializationCell->True],
Cell[22745, 842, 148, 4, 59, "Input",
  InitializationCell->True],
Cell[22896, 848, 220, 4, 43, "Input",
  InitializationCell->True],
Cell[23119, 854, 74, 1, 43, "Input"],
Cell[23196, 857, 220, 5, 44, "Input"],
Cell[23419, 864, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[23492, 868, 1638, 26, 284, "Input"],
Cell[25133, 896, 68, 2, 27, "Input",
  InitializationCell->True]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

